@@ -39,10 +39,13 @@ import org.apache.commons.configuration.Configuration;
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hadoop.hbase.HBaseConfiguration;
-import org.apache.hadoop.hbase.HColumnDescriptor;
-import org.apache.hadoop.hbase.HTableDescriptor;
 import org.apache.hadoop.hbase.NamespaceDescriptor;
+import org.apache.hadoop.hbase.client.Admin;
+import org.apache.hadoop.hbase.client.ColumnFamilyDescriptor;
+import org.apache.hadoop.hbase.client.Connection;
+import org.apache.hadoop.hbase.client.ConnectionFactory;
 import org.apache.hadoop.hbase.client.HBaseAdmin;
+import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.security.UserGroupInformation;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -84,6 +87,7 @@ public class HBaseBridge {
     private static final String ATTR_TABLE_ISCOMPACTION_ENABLED      = "isCompactionEnabled";
     private static final String ATTR_TABLE_REPLICATION_PER_REGION    = "replicasPerRegion";
     private static final String ATTR_TABLE_DURABLILITY               = "durability";
+    private static final String ATTR_TABLE_NORMALIZATION_ENABLED     = "isNormalizationEnabled";
 
     // column family metadata
     private static final String ATTR_CF_BLOOMFILTER_TYPE             = "bloomFilterType";
@@ -102,6 +106,10 @@ public class HBaseBridge {
     private static final String ATTR_CF_EVICT_BLOCK_ONCLOSE          = "evictBlocksOnClose";
     private static final String ATTR_CF_PREFETCH_BLOCK_ONOPEN        = "prefetchBlocksOnOpen";
     private static final String ATTRIBUTE_QUALIFIED_NAME             = "qualifiedName";
+    private static final String ATTR_CF_INMEMORY_COMPACTION_POLICY   = "inMemoryCompactionPolicy";
+    private static final String ATTR_CF_MOB_COMPATCTPARTITION_POLICY = "mobCompactPartitionPolicy";
+    private static final String ATTR_CF_MOB_ENABLED                  = "isMobEnabled";
+    private static final String ATTR_CF_NEW_VERSION_BEHAVIOR         = "newVersionBehavior";
 
     private static final String HBASE_NAMESPACE_QUALIFIED_NAME            = "%s@%s";
     private static final String HBASE_TABLE_QUALIFIED_NAME_FORMAT         = "%s:%s@%s";
@@ -109,7 +117,7 @@ public class HBaseBridge {
 
     private final String         clusterName;
     private final AtlasClientV2  atlasClientV2;
-    private final HBaseAdmin     hbaseAdmin;
+    private final Admin          hbaseAdmin;
 
 
     public static void main(String[] args) {
@@ -203,11 +211,13 @@ public class HBaseBridge {
 
         LOG.info("checking HBase availability..");
 
-        HBaseAdmin.checkHBaseAvailable(conf);
+        HBaseAdmin.available(conf);
 
         LOG.info("HBase is available");
 
-        hbaseAdmin = new HBaseAdmin(conf);
+        Connection conn = ConnectionFactory.createConnection(conf);
+
+        hbaseAdmin = conn.getAdmin();
     }
 
     private boolean importHBaseEntities(String namespaceToImport, String tableToImport) throws Exception {
@@ -242,11 +252,11 @@ public class HBaseBridge {
     }
 
     public void importTable(final String tableName) throws Exception {
-        String             tableNameStr = null;
-        HTableDescriptor[] htds         = hbaseAdmin.listTables(Pattern.compile(tableName));
+        String            tableNameStr = null;
+        TableDescriptor[] htds         = hbaseAdmin.listTables(Pattern.compile(tableName));
 
         if (ArrayUtils.isNotEmpty(htds)) {
-            for (HTableDescriptor htd : htds) {
+            for (TableDescriptor htd : htds) {
                 String tblNameWithNameSpace    = htd.getTableName().getNameWithNamespaceInclAsString();
                 String tblNameWithOutNameSpace = htd.getTableName().getNameAsString();
 
@@ -267,7 +277,7 @@ public class HBaseBridge {
                 String                 nsName       = new String(nsByte);
                 NamespaceDescriptor    nsDescriptor = hbaseAdmin.getNamespaceDescriptor(nsName);
                 AtlasEntityWithExtInfo entity       = createOrUpdateNameSpace(nsDescriptor);
-                HColumnDescriptor[]    hcdts        = htd.getColumnFamilies();
+                ColumnFamilyDescriptor[]    hcdts        = htd.getColumnFamilies();
 
                 createOrUpdateTable(nsName, tableNameStr, entity.getEntity(), htd, hcdts);
             }
@@ -287,11 +297,11 @@ public class HBaseBridge {
             }
         }
 
-        HTableDescriptor[] htds = hbaseAdmin.listTables();
+        TableDescriptor[] htds = hbaseAdmin.listTables();
 
         if (ArrayUtils.isNotEmpty(htds)) {
-            for (HTableDescriptor htd : htds) {
-                String tableName = htd.getNameAsString();
+            for (TableDescriptor htd : htds) {
+                String tableName = htd.getTableName().getNameAsString();
 
                 importTable(tableName);
             }
@@ -301,7 +311,7 @@ public class HBaseBridge {
     private void importNameSpaceWithTable(String namespaceToImport, String tableToImport) throws Exception {
         importNameSpace(namespaceToImport);
 
-        List<HTableDescriptor> hTableDescriptors = new ArrayList<>();
+        List<TableDescriptor> hTableDescriptors = new ArrayList<>();
 
         if (StringUtils.isEmpty(tableToImport)) {
             List<NamespaceDescriptor> matchingNameSpaceDescriptors = getMatchingNameSpaces(namespaceToImport);
@@ -312,13 +322,13 @@ public class HBaseBridge {
         } else {
             tableToImport = namespaceToImport +":" + tableToImport;
 
-            HTableDescriptor[] htds = hbaseAdmin.listTables(Pattern.compile(tableToImport));
+            TableDescriptor[] htds = hbaseAdmin.listTables(Pattern.compile(tableToImport));
 
             hTableDescriptors.addAll(Arrays.asList(htds));
         }
 
         if (CollectionUtils.isNotEmpty(hTableDescriptors)) {
-            for (HTableDescriptor htd : hTableDescriptors) {
+            for (TableDescriptor htd : hTableDescriptors) {
                 String tblName = htd.getTableName().getNameAsString();
 
                 importTable(tblName);
@@ -343,11 +353,11 @@ public class HBaseBridge {
         return ret;
     }
 
-    private List<HTableDescriptor> getTableDescriptors(List<NamespaceDescriptor> namespaceDescriptors) throws Exception {
-        List<HTableDescriptor> ret = new ArrayList<>();
+    private List<TableDescriptor> getTableDescriptors(List<NamespaceDescriptor> namespaceDescriptors) throws Exception {
+        List<TableDescriptor> ret = new ArrayList<>();
 
         for(NamespaceDescriptor namespaceDescriptor:namespaceDescriptors) {
-            HTableDescriptor[] tableDescriptors = hbaseAdmin.listTableDescriptorsByNamespace(namespaceDescriptor.getName());
+            TableDescriptor[] tableDescriptors = hbaseAdmin.listTableDescriptorsByNamespace(namespaceDescriptor.getName());
 
             ret.addAll(Arrays.asList(tableDescriptors));
         }
@@ -378,7 +388,7 @@ public class HBaseBridge {
         return nsEntity;
     }
 
-    protected  AtlasEntityWithExtInfo  createOrUpdateTable(String nameSpace, String tableName, AtlasEntity nameSapceEntity, HTableDescriptor htd, HColumnDescriptor[] hcdts) throws Exception {
+    protected  AtlasEntityWithExtInfo  createOrUpdateTable(String nameSpace, String tableName, AtlasEntity nameSapceEntity, TableDescriptor htd, ColumnFamilyDescriptor[] hcdts) throws Exception {
         String                 owner            = htd.getOwnerString();
         String                 tblQualifiedName = getTableQualifiedName(clusterName, nameSpace, tableName);
         AtlasEntityWithExtInfo ret              = findTableEntityInAtlas(tblQualifiedName);
@@ -418,13 +428,13 @@ public class HBaseBridge {
         return ret;
     }
 
-    protected List<AtlasEntityWithExtInfo> createOrUpdateColumnFamilies(String nameSpace, String tableName, String owner, HColumnDescriptor[] hcdts , AtlasEntity tableEntity) throws Exception {
+    protected List<AtlasEntityWithExtInfo> createOrUpdateColumnFamilies(String nameSpace, String tableName, String owner, ColumnFamilyDescriptor[] hcdts , AtlasEntity tableEntity) throws Exception {
         List<AtlasEntityWithExtInfo > ret = new ArrayList<>();
 
         if (hcdts != null) {
             AtlasObjectId tableId = AtlasTypeUtil.getAtlasObjectId(tableEntity);
 
-            for (HColumnDescriptor columnFamilyDescriptor : hcdts) {
+            for (ColumnFamilyDescriptor columnFamilyDescriptor : hcdts) {
                 String                 cfName          = columnFamilyDescriptor.getNameAsString();
                 String                 cfQualifiedName = getColumnFamilyQualifiedName(clusterName, nameSpace, tableName, cfName);
                 AtlasEntityWithExtInfo cfEntity        = findColumnFamiltyEntityInAtlas(cfQualifiedName);
@@ -516,7 +526,7 @@ public class HBaseBridge {
         return ret;
     }
 
-    private AtlasEntity getTableEntity(String nameSpace, String tableName, String owner, AtlasEntity nameSpaceEntity, HTableDescriptor htd, AtlasEntity atlasEntity) {
+    private AtlasEntity getTableEntity(String nameSpace, String tableName, String owner, AtlasEntity nameSpaceEntity, TableDescriptor htd, AtlasEntity atlasEntity) {
         AtlasEntity ret = null;
 
         if (atlasEntity == null) {
@@ -539,11 +549,12 @@ public class HBaseBridge {
         ret.setAttribute(ATTR_TABLE_ISREADONLY, htd.isReadOnly());
         ret.setAttribute(ATTR_TABLE_ISCOMPACTION_ENABLED, htd.isCompactionEnabled());
         ret.setAttribute(ATTR_TABLE_DURABLILITY, (htd.getDurability() != null ? htd.getDurability().name() : null));
+        ret.setAttribute(ATTR_TABLE_NORMALIZATION_ENABLED, htd.isNormalizationEnabled());
 
         return ret;
     }
 
-    private AtlasEntity getColumnFamilyEntity(String nameSpace, String tableName, String owner, HColumnDescriptor hcdt, AtlasObjectId tableId, AtlasEntity atlasEntity){
+    private AtlasEntity getColumnFamilyEntity(String nameSpace, String tableName, String owner, ColumnFamilyDescriptor hcdt, AtlasObjectId tableId, AtlasEntity atlasEntity){
         AtlasEntity ret = null;
 
         if (atlasEntity == null) {
@@ -576,6 +587,10 @@ public class HBaseBridge {
         ret.setAttribute(ATTR_CF_MIN_VERSIONS, hcdt.getMinVersions());
         ret.setAttribute(ATTR_CF_PREFETCH_BLOCK_ONOPEN, hcdt.isPrefetchBlocksOnOpen());
         ret.setAttribute(ATTR_CF_TTL, hcdt.getTimeToLive());
+        ret.setAttribute(ATTR_CF_INMEMORY_COMPACTION_POLICY, (hcdt.getInMemoryCompaction() != null ? hcdt.getInMemoryCompaction().name():null));
+        ret.setAttribute(ATTR_CF_MOB_COMPATCTPARTITION_POLICY, ( hcdt.getMobCompactPartitionPolicy() != null ? hcdt.getMobCompactPartitionPolicy().name():null));
+        ret.setAttribute(ATTR_CF_MOB_ENABLED,hcdt.isMobEnabled());
+        ret.setAttribute(ATTR_CF_NEW_VERSION_BEHAVIOR,hcdt.isNewVersionBehavior());
 
         return ret;
     }
