@@ -22,6 +22,7 @@ import com.google.common.annotations.VisibleForTesting;
 import org.apache.atlas.ApplicationProperties;
 import org.apache.atlas.AtlasClient;
 import org.apache.atlas.AtlasClientV2;
+import org.apache.atlas.AtlasServiceException;
 import org.apache.atlas.hive.bridge.ColumnLineageUtils;
 import org.apache.atlas.hive.bridge.HiveMetaStoreBridge;
 import org.apache.atlas.hive.hook.HiveHookIT;
@@ -67,7 +68,10 @@ import java.util.Set;
 import java.util.SortedMap;
 import java.util.SortedSet;
 
+import static com.sun.jersey.api.client.ClientResponse.Status.NOT_FOUND;
 import static org.apache.atlas.hive.bridge.HiveMetaStoreBridge.HDFS_PATH;
+import static org.apache.atlas.hive.hook.events.BaseHiveEvent.ATTRIBUTE_QUALIFIED_NAME;
+import static org.apache.atlas.hive.model.HiveDataTypes.HIVE_DB;
 import static org.testng.Assert.assertEquals;
 import static org.testng.Assert.assertNotNull;
 import static org.testng.Assert.assertTrue;
@@ -82,7 +86,7 @@ public class HiveITBase {
     protected static final String DGI_URL      = "http://localhost:21000/";
     protected static final String CLUSTER_NAME = "primary";
     protected static final String PART_FILE    = "2015-01-01";
-    protected static final String INPUTS       = "inputs";;
+    protected static final String INPUTS       = "inputs";
     protected static final String OUTPUTS      = "outputs";
 
 
@@ -103,35 +107,46 @@ public class HiveITBase {
         //Set-up hive session
         conf = new HiveConf();
         conf.setClassLoader(Thread.currentThread().getContextClassLoader());
+        conf.set("hive.metastore.event.listeners", "");
+
+        // 'driver' using this configuration will be used for tests in HiveHookIT
+        //  HiveHookIT will use this driver to test post-execution hooks in HiveServer2.
+        //  initialize 'driver' with HMS hook disabled.
         driver = new Driver(conf);
-        ss = new SessionState(conf);
-        ss = SessionState.start(ss);
+        ss     = new SessionState(conf);
+        ss     = SessionState.start(ss);
 
         SessionState.setCurrentSessionState(ss);
 
         Configuration configuration = ApplicationProperties.get();
 
         String[] atlasEndPoint = configuration.getStringArray(HiveMetaStoreBridge.ATLAS_ENDPOINT);
+
         if (atlasEndPoint == null || atlasEndPoint.length == 0) {
             atlasEndPoint = new String[] { DGI_URL };
         }
 
         if (!AuthenticationUtil.isKerberosAuthenticationEnabled()) {
             atlasClientV2 = new AtlasClientV2(atlasEndPoint, new String[]{"admin", "admin"});
-            atlasClient = new AtlasClient(atlasEndPoint, new String[]{"admin", "admin"});
+            atlasClient   = new AtlasClient(atlasEndPoint, new String[]{"admin", "admin"});
         } else {
             atlasClientV2 = new AtlasClientV2(atlasEndPoint);
-            atlasClient = new AtlasClient(atlasEndPoint);
-
+            atlasClient   = new AtlasClient(atlasEndPoint);
         }
 
         hiveMetaStoreBridge = new HiveMetaStoreBridge(configuration, conf, atlasClientV2);
 
         HiveConf conf = new HiveConf();
+
         conf.set("hive.exec.post.hooks", "");
+
         SessionState ss = new SessionState(conf);
         ss = SessionState.start(ss);
         SessionState.setCurrentSessionState(ss);
+
+        // 'driverWithoutContext' using this configuration will be used for tests in HiveMetastoreHookIT
+        //  HiveMetastoreHookIT will use this driver to test event listeners in HiveMetastore.
+        //  initialize 'driverWithoutContext' with HiveServer2 post execution hook disabled.
         driverWithoutContext = new Driver(conf);
     }
 
@@ -149,9 +164,11 @@ public class HiveITBase {
 
     protected void runCommandWithDelay(Driver driver, String cmd, int sleepMs) throws Exception {
         LOG.debug("Running command '{}'", cmd);
-        ss.setCommandType(null);
+
         CommandProcessorResponse response = driver.run(cmd);
+
         assertEquals(response.getResponseCode(), 0);
+
         if (sleepMs != 0) {
             Thread.sleep(sleepMs);
         }
@@ -183,11 +200,15 @@ public class HiveITBase {
     }
 
     protected String random() {
-        return RandomStringUtils.randomAlphanumeric(10);
+        return RandomStringUtils.randomAlphanumeric(10).toLowerCase();
     }
 
     protected String tableName() {
-        return "table" + random();
+        return "table_" + random();
+    }
+
+    protected String dbName() {
+        return "db_" + random();
     }
 
     protected String assertTableIsRegistered(String dbName, String tableName) throws Exception {
@@ -318,12 +339,35 @@ public class HiveITBase {
     }
 
     protected String assertDatabaseIsRegistered(String dbName, AssertPredicate assertPredicate) throws Exception {
-        LOG.debug("Searching for database {}", dbName);
+        LOG.debug("Searching for database: {}", dbName);
+
         String dbQualifiedName = HiveMetaStoreBridge.getDBQualifiedName(CLUSTER_NAME, dbName);
-        return assertEntityIsRegistered(HiveDataTypes.HIVE_DB.getName(), REFERENCEABLE_ATTRIBUTE_NAME,
-                dbQualifiedName, assertPredicate);
+
+        return assertEntityIsRegistered(HIVE_DB.getName(), REFERENCEABLE_ATTRIBUTE_NAME, dbQualifiedName, assertPredicate);
     }
 
+    public void assertDatabaseIsNotRegistered(String dbName) throws Exception {
+        LOG.debug("Searching for database {}", dbName);
+        String dbQualifiedName = HiveMetaStoreBridge.getDBQualifiedName(CLUSTER_NAME, dbName);
+        assertEntityIsNotRegistered(HIVE_DB.getName(), ATTRIBUTE_QUALIFIED_NAME, dbQualifiedName);
+    }
+
+    protected void assertEntityIsNotRegistered(final String typeName, final String property, final String value) throws Exception {
+        // wait for sufficient time before checking if entity is not available.
+        long waitTime = 2000;
+        LOG.debug("Waiting for {} msecs, before asserting entity is not registered.", waitTime);
+        Thread.sleep(waitTime);
+
+        try {
+            atlasClientV2.getEntityByAttribute(typeName, Collections.singletonMap(property, value));
+
+            fail(String.format("Entity was not supposed to exist for typeName = %s, attributeName = %s, attributeValue = %s", typeName, property, value));
+        } catch (AtlasServiceException e) {
+            if (e.getStatus() == NOT_FOUND) {
+                return;
+            }
+        }
+    }
 
     protected AtlasEntity getAtlasEntityByType(String type, String id) throws Exception {
         AtlasEntity atlasEntity = null;
