@@ -41,8 +41,10 @@ import org.apache.atlas.type.AtlasTypeUtil;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.hadoop.fs.Path;
+import org.apache.hadoop.hive.conf.HiveConf;
 import org.apache.hadoop.hive.metastore.TableType;
 import org.apache.hadoop.hive.metastore.api.hive_metastoreConstants;
+import org.apache.hadoop.hive.ql.Driver;
 import org.apache.hadoop.hive.ql.hooks.Entity;
 import org.apache.hadoop.hive.ql.hooks.ReadEntity;
 import org.apache.hadoop.hive.ql.hooks.WriteEntity;
@@ -54,25 +56,40 @@ import org.apache.hadoop.security.UserGroupInformation;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.testng.Assert;
+import org.testng.annotations.BeforeClass;
 import org.testng.annotations.Test;
 
-import java.io.File;
 import java.text.ParseException;
 import java.util.*;
 
 import static org.apache.atlas.AtlasClient.NAME;
 import static org.apache.atlas.hive.hook.events.BaseHiveEvent.*;
-import static org.testng.Assert.assertEquals;
-import static org.testng.Assert.assertNotEquals;
-import static org.testng.Assert.assertNotNull;
-import static org.testng.Assert.assertTrue;
-import static org.testng.Assert.fail;
+import static org.testng.Assert.*;
 
 public class HiveHookIT extends HiveITBase {
     private static final Logger LOG = LoggerFactory.getLogger(HiveHookIT.class);
 
     private static final String PART_FILE  = "2015-01-01";
 
+    private Driver driverWithNoHook;
+
+    @BeforeClass
+    public void setUp() throws Exception {
+        //  initialize 'driverWithNoHook' with HiveServer2 hook and HiveMetastore hook disabled
+        HiveConf conf = new HiveConf();
+        conf.set("hive.exec.post.hooks", "");
+        conf.set("hive.metastore.event.listeners", "");
+
+        SessionState ss = new SessionState(conf);
+        ss = SessionState.start(ss);
+        SessionState.setCurrentSessionState(ss);
+
+        // Initialize 'driverWithNoHook'  with HS2 hook disabled and HMS hook disabled.
+        driverWithNoHook = new Driver(conf);
+
+        super.setUp();
+    }
+
     @Test
     public void testCreateDatabase() throws Exception {
         String dbName = "db" + random();
@@ -89,7 +106,7 @@ public class HiveHookIT extends HiveITBase {
 
         //There should be just one entity per dbname
         runCommand("drop database " + dbName);
-        assertDBIsNotRegistered(dbName);
+        assertDatabaseIsNotRegistered(dbName);
 
         runCommand("create database " + dbName);
         dbId = assertDatabaseIsRegistered(dbName);
@@ -196,14 +213,12 @@ public class HiveHookIT extends HiveITBase {
     }
 
     private Set<ReadEntity> getInputs(String inputName, Entity.Type entityType) throws HiveException {
-        final ReadEntity entity = new ReadEntity();
+        final ReadEntity entity;
 
         if (Entity.Type.DFS_DIR.equals(entityType)) {
-            entity.setName(lower(new Path(inputName).toString()));
-            entity.setTyp(Entity.Type.DFS_DIR);
+            entity = new TestReadEntity(lower(new Path(inputName).toString()), entityType);
         } else {
-            entity.setName(getQualifiedTblName(inputName));
-            entity.setTyp(entityType);
+            entity = new TestReadEntity(getQualifiedTblName(inputName), entityType);
         }
 
         if (entityType == Entity.Type.TABLE) {
@@ -214,14 +229,12 @@ public class HiveHookIT extends HiveITBase {
     }
 
     private Set<WriteEntity> getOutputs(String inputName, Entity.Type entityType) throws HiveException {
-        final WriteEntity entity = new WriteEntity();
+        final WriteEntity entity;
 
         if (Entity.Type.DFS_DIR.equals(entityType) || Entity.Type.LOCAL_DIR.equals(entityType)) {
-            entity.setName(lower(new Path(inputName).toString()));
-            entity.setTyp(entityType);
+            entity = new TestWriteEntity(lower(new Path(inputName).toString()), entityType);
         } else {
-            entity.setName(getQualifiedTblName(inputName));
-            entity.setTyp(entityType);
+            entity = new TestWriteEntity(getQualifiedTblName(inputName), entityType);
         }
 
         if (entityType == Entity.Type.TABLE) {
@@ -591,8 +604,8 @@ public class HiveHookIT extends HiveITBase {
     @Test
     public void testInsertIntoLocalDir() throws Exception {
         String tableName       = createTable();
-        File   randomLocalPath = File.createTempFile("hiverandom", ".tmp");
-        String query           = "insert overwrite LOCAL DIRECTORY '" + randomLocalPath.getAbsolutePath() + "' select id, name from " + tableName;
+        String randomLocalPath = mkdir("hiverandom.tmp");
+        String query           = "insert overwrite LOCAL DIRECTORY '" + randomLocalPath + "' select id, name from " + tableName;
 
         runCommand(query);
 
@@ -715,7 +728,6 @@ public class HiveHookIT extends HiveITBase {
         Set<ReadEntity> inputs = getInputs(tableName, Entity.Type.TABLE);
         Set<WriteEntity> outputs = getOutputs(insertTableName, Entity.Type.TABLE);
 
-        outputs.iterator().next().setName(getQualifiedTblName(insertTableName + HiveMetaStoreBridge.TEMP_TABLE_PREFIX + SessionState.get().getSessionId()));
         outputs.iterator().next().setWriteType(WriteEntity.WriteType.INSERT);
 
         validateProcess(constructEvent(query,  HiveOperation.QUERY, inputs, outputs));
@@ -1329,7 +1341,7 @@ public class HiveHookIT extends HiveITBase {
         String tableName     = tableName();
         String createCommand = "create table " + tableName + " (id int, name string)";
 
-        driverWithoutContext.run(createCommand);
+        driverWithNoHook.run(createCommand);
 
         assertTableIsNotRegistered(DEFAULT_DB, tableName);
 
@@ -1392,7 +1404,7 @@ public class HiveHookIT extends HiveITBase {
         String testPath  = createTestDFSPath("testBaseDir");
         String query     = "alter table " + tableName + " set location '" + testPath + "'";
 
-        runCommand(query);
+        runCommandWithDelay(query, 5000);
 
         assertTableIsRegistered(DEFAULT_DB, tableName, new AssertPredicate() {
             @Override
@@ -1536,19 +1548,13 @@ public class HiveHookIT extends HiveITBase {
     }
 
     private WriteEntity getPartitionOutput() {
-        WriteEntity partEntity = new WriteEntity();
-
-        partEntity.setName(PART_FILE);
-        partEntity.setTyp(Entity.Type.PARTITION);
+        TestWriteEntity partEntity = new TestWriteEntity(PART_FILE, Entity.Type.PARTITION);
 
         return partEntity;
     }
 
     private ReadEntity getPartitionInput() {
-        ReadEntity partEntity = new ReadEntity();
-
-        partEntity.setName(PART_FILE);
-        partEntity.setTyp(Entity.Type.PARTITION);
+        ReadEntity partEntity = new TestReadEntity(PART_FILE, Entity.Type.PARTITION);
 
         return partEntity;
     }
@@ -1579,7 +1585,7 @@ public class HiveHookIT extends HiveITBase {
             assertTableIsNotRegistered(dbName, tableNames[i]);
         }
 
-        assertDBIsNotRegistered(dbName);
+        assertDatabaseIsNotRegistered(dbName);
     }
 
     @Test
@@ -1626,14 +1632,14 @@ public class HiveHookIT extends HiveITBase {
         //Test Deletion of a non existing DB
         String dbName = "nonexistingdb";
 
-        assertDBIsNotRegistered(dbName);
+        assertDatabaseIsNotRegistered(dbName);
 
         String query = String.format("drop database if exists %s cascade", dbName);
 
         runCommand(query);
 
         //Should have no effect
-        assertDBIsNotRegistered(dbName);
+        assertDatabaseIsNotRegistered(dbName);
     }
 
     @Test
@@ -1958,33 +1964,10 @@ public class HiveHookIT extends HiveITBase {
         assertEntityIsNotRegistered(HiveDataTypes.HIVE_TABLE.getName(), ATTRIBUTE_QUALIFIED_NAME, tableQualifiedName);
     }
 
-    private void assertDBIsNotRegistered(String dbName) throws Exception {
-        LOG.debug("Searching for database {}", dbName);
-        String dbQualifiedName = HiveMetaStoreBridge.getDBQualifiedName(CLUSTER_NAME, dbName);
-        assertEntityIsNotRegistered(HiveDataTypes.HIVE_DB.getName(), ATTRIBUTE_QUALIFIED_NAME, dbQualifiedName);
-    }
-
     private String assertTableIsRegistered(String dbName, String tableName, AssertPredicate assertPredicate) throws Exception {
         return assertTableIsRegistered(dbName, tableName, assertPredicate, false);
     }
 
-    private void assertEntityIsNotRegistered(final String typeName, final String property, final String value) throws Exception {
-        waitFor(80000, new Predicate() {
-            @Override
-            public void evaluate() throws Exception {
-                try {
-                    atlasClientV2.getEntityByAttribute(typeName, Collections.singletonMap(property, value));
-                } catch (AtlasServiceException e) {
-                    if (e.getStatus() == ClientResponse.Status.NOT_FOUND) {
-                        return;
-                    }
-                }
-                fail(String.format("Entity was not supposed to exist for typeName = %s, attributeName = %s, "
-                        + "attributeValue = %s", typeName, property, value));
-            }
-        });
-    }
-
     @Test
     public void testLineage() throws Exception {
         String table1 = createTable(false);
@@ -2016,10 +1999,6 @@ public class HiveHookIT extends HiveITBase {
         runCommand("show transactions");
     }
 
-    private String dbName() {
-        return "db" + random();
-    }
-
     private String createDatabase() throws Exception {
         String dbName = dbName();
 
@@ -2056,4 +2035,38 @@ public class HiveHookIT extends HiveITBase {
 
         return tableName;
     }
+
+    // ReadEntity class doesn't offer a constructor that takes (name, type). A hack to get the tests going!
+    private static class TestReadEntity extends ReadEntity {
+        private final String      name;
+        private final Entity.Type type;
+
+        public TestReadEntity(String name, Entity.Type type) {
+            this.name = name;
+            this.type = type;
+        }
+
+        @Override
+        public String getName() { return name; }
+
+        @Override
+        public Entity.Type getType() { return type; }
+    }
+
+    // WriteEntity class doesn't offer a constructor that takes (name, type). A hack to get the tests going!
+    private static class TestWriteEntity extends WriteEntity {
+        private final String      name;
+        private final Entity.Type type;
+
+        public TestWriteEntity(String name, Entity.Type type) {
+            this.name = name;
+            this.type = type;
+        }
+
+        @Override
+        public String getName() { return name; }
+
+        @Override
+        public Entity.Type getType() { return type; }
+    }
 }
