@@ -576,34 +576,6 @@ define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums',
             });
         }
     }
-
-    Utils.findAndMergeRelationShipEntity = function(options) {
-        var attributeObject = options.attributeObject,
-            relationshipAttributes = options.relationshipAttributes;
-        _.each(attributeObject, function(val, key) {
-            var attributVal = val;
-            if (relationshipAttributes && relationshipAttributes[key]) {
-                var relationShipVal = relationshipAttributes[key];
-                if (_.isObject(val)) {
-                    if (_.isArray(val)) {
-                        _.each(val, function(attr) {
-                            if (attr && attr.attributes === undefined) {
-                                var entityFound = _.find(relationShipVal, { guid: attr.guid });
-                                if (entityFound) {
-                                    attr.attributes = _.omit(entityFound, 'typeName', 'guid', 'entityStatus');
-                                    attr.status = entityFound.entityStatus;
-                                }
-                            }
-                        });
-                    } else if (relationShipVal && val.attributes === undefined) {
-                        val.attributes = _.omit(relationShipVal, 'typeName', 'guid', 'entityStatus');
-                        val.status = relationShipVal.entityStatus;
-                    }
-                }
-            }
-        })
-    }
-
     Utils.getNestedSuperTypes = function(options) {
         var data = options.data,
             collection = options.collection,
@@ -843,5 +815,28 @@ define(['require', 'utils/Globals', 'pnotify', 'utils/Messages', 'utils/Enums',
             this.attr(attributeName, firstString);
         }
     }
+
+    Utils.millisecondsToTime = function(duration) {
+        var milliseconds = parseInt((duration % 1000) / 100),
+            seconds = parseInt((duration / 1000) % 60),
+            minutes = parseInt((duration / (1000 * 60)) % 60),
+            hours = parseInt((duration / (1000 * 60 * 60)) % 24);
+
+        hours = (hours < 10) ? "0" + hours : hours;
+        minutes = (minutes < 10) ? "0" + minutes : minutes;
+        seconds = (seconds < 10) ? "0" + seconds : seconds;
+
+        return hours + ":" + minutes + ":" + seconds + "." + milliseconds;
+    }
+    Utils.togglePropertyRelationshipTableEmptyValues = function(object) {
+        var inputSelector = object.inputType,
+            tableEl = object.tableEl;
+        if (inputSelector.prop('checked') == true) {
+            tableEl.removeClass('hide-empty-value');
+        } else {
+            tableEl.addClass('hide-empty-value');
+        }
+
+    }
     return Utils;
 });
\ No newline at end of file
