@@ -141,11 +141,6 @@ define(['require',
                         referredEntities: this.entityObject.referredEntities
                     });
 
-                    Utils.findAndMergeRelationShipEntity({
-                        attributeObject: collectionJSON.attributes,
-                        relationshipAttributes: collectionJSON.relationshipAttributes
-                    });
-
                     // check if entity is process
                     var isProcess = false,
                         superTypes = Utils.getNestedSuperTypes({ data: this.activeEntityDef.toJSON(), collection: this.entityDefCollection }),
@@ -222,7 +217,7 @@ define(['require',
                         }
                         if (collectionJSON.attributes && collectionJSON.attributes.columns) {
                             var valueSorted = _.sortBy(collectionJSON.attributes.columns, function(val) {
-                                return val.attributes && val.attributes.position
+                                return val.attributes.position
                             });
                             collectionJSON.attributes.columns = valueSorted;
                         }
@@ -418,7 +413,6 @@ define(['require',
                 var that = this,
                     termData = "";
                 _.each(data, function(val) {
-                    console.log(val.guid)
                     if (val.relationshipStatus == "ACTIVE") {
                         termData += '<span class="btn btn-action btn-sm btn-icon btn-blue" title=' + _.escape(val.displayText) + ' data-id="termClick"><span>' + _.escape(val.displayText) + '</span><i class="fa fa-close" data-id="deleteTerm" data-guid="' + val.guid + '" data-type="term" title="Remove Term"></i></span>';
                     }
