@@ -130,16 +130,8 @@ define(['require',
             onRender: function() {
                 var that = this;
                 this.fetchGraphData();
-
-
                 if (platform.name === "IE") {
                     this.$('svg').css('opacity', '0');
-
-                }
-
-                if (platform.name === "Microsoft Edge" || platform.name === "IE") {
-                    $(that.ui.saveSvg).hide();
-
                 }
                 if (this.layoutRendered) {
                     this.layoutRendered();
@@ -169,10 +161,10 @@ define(['require',
                 var icon = $(e.currentTarget).find('i'),
                     panel = $(e.target).parents('.tab-pane').first();
                 icon.toggleClass('fa-expand fa-compress');
-                if (icon.hasClass('fa-expand')) {
-                    icon.parent('button').attr("data-original-title", "Full Screen");
-                } else {
-                    icon.parent('button').attr("data-original-title", "Default View");
+                if(icon.hasClass('fa-expand')){
+                    icon.parent('button').attr("data-original-title","Full Screen");
+                }else{
+                    icon.parent('button').attr("data-original-title","Default View");
                 }
                 panel.toggleClass('fullscreen-mode');
             },
@@ -491,9 +483,6 @@ define(['require',
                     "translate(" + this.zoom.translate() + ")" +
                     "scale(" + this.zoom.scale() + ")"
                 );
-                LineageUtils.refreshGraphForIE({
-                    edgeEl: this.$('svg .edgePath')
-                });
             },
             interpolateZoom: function(translate, scale, that, zoom) {
                 return d3.transition().duration(350).tween("zoom", function() {
@@ -512,8 +501,6 @@ define(['require',
                     width = this.$('svg').width(),
                     height = this.$('svg').height(),
                     imageObject = {};
-                $('.resizeGraph').css("height", height + "px");
-
                 this.g.nodes().forEach(function(v) {
                     var node = that.g.node(v);
                     // Round the corners of the nodes
@@ -565,54 +552,38 @@ define(['require',
                         .attr("width", "100%")
                         .attr("height", "100%")
                         .append('image')
-                        .attr("href", function(d) {
+                        .attr("xlink:href", function(d) {
                             var that = this;
                             if (node) {
-                                // to check for IE-10
-                                var originLink = window.location.origin;
-                                if (platform.name === "IE") {
-                                    originLink = window.location.protocol + "//" + window.location.host;
-                                }
                                 var imageIconPath = Utils.getEntityIconPath({ entityData: node }),
-                                    imagePath = ((originLink + Utils.getBaseUrl(window.location.pathname)) + imageIconPath);
+                                    imagePath = ((window.location.origin + Utils.getBaseUrl(window.location.pathname)) + imageIconPath);
 
-                                var getImageData = function(options) {
-                                    var imagePath = options.imagePath,
-                                        ajaxOptions = {
-                                            "url": imagePath,
-                                            "method": "get",
-                                            "async": false,
-                                        }
+                                var xhr = new XMLHttpRequest();
+                                xhr.responseType = 'blob';
 
-                                    if (platform.name !== "IE") {
-                                        ajaxOptions["mimeType"] = "text/plain; charset=x-user-defined";
-                                    }
-                                    $.ajax(ajaxOptions)
-                                        .always(function(data, status, xhr) {
-                                            if (data.status == 404) {
-                                                getImageData({
-                                                    "imagePath": Utils.getEntityIconPath({ entityData: node, errorUrl: imagePath }),
-                                                    "imageIconPath": imageIconPath
-                                                });
-                                            } else if (data) {
-                                                if (platform.name !== "IE") {
-                                                    imageObject[imageIconPath] = 'data:image/png;base64,' + LineageUtils.base64Encode({ "data": data });
-                                                } else {
-                                                    imageObject[imageIconPath] = imagePath;
-                                                }
-                                            }
+                                xhr.onload = function() {
+                                    var reader = new FileReader();
+                                    reader.onloadend = function() {
+                                        _.each(imageObject[imageIconPath], function(obj) {
+                                            obj.attr("xlink:href", reader.result);
                                         });
-                                }
-                                if (_.keys(imageObject).indexOf(imageIconPath) === -1) {
-                                    getImageData({
-                                        "imagePath": imagePath,
-                                        "imageIconPath": imageIconPath
-                                    });
-                                }
+                                        imageObject[imageIconPath] = reader.result;
+                                    }
 
+                                    if (xhr.status != 404) {
+                                        reader.readAsDataURL(xhr.response);
+                                    } else {
+                                        xhr.open('GET',
+                                            Utils.getEntityIconPath({ entityData: node, errorUrl: this.responseURL }),
+                                            true);
+                                        xhr.send();
+                                    }
+                                }
                                 if (_.isUndefined(imageObject[imageIconPath])) {
                                     // before img success
                                     imageObject[imageIconPath] = [d3.select(that)];
+                                    xhr.open('GET', imagePath, true);
+                                    xhr.send();
                                 } else if (_.isArray(imageObject[imageIconPath])) {
                                     // before img success
                                     imageObject[imageIconPath].push(d3.select(that));
@@ -758,7 +729,6 @@ define(['require',
                             return;
                         }
                         that.$('svg').removeClass('hover');
-                        that.$('svg').removeClass('hover-active');
                         LineageUtils.onHoverFade({
                             opacity: 1,
                             selectedNode: d,
@@ -820,7 +790,6 @@ define(['require',
                     guid: that.guid,
                     svg: that.$('svg'),
                     g: this.g,
-                    edgeEl: $('svg .edgePath'),
                     afterCenterZoomed: function(options) {
                         var newScale = options.newScale,
                             newTranslate = options.newTranslate;
@@ -829,16 +798,28 @@ define(['require',
                     }
                 }).init();
                 zoom.event(svg);
+                //svg.attr('height', this.g.graph().height * initialScale + 40);
                 if (platform.name === "IE") {
-                    LineageUtils.refreshGraphForIE({
-                        edgeEl: this.$('svg .edgePath')
+                    this.IEGraphRenderDone = 0;
+                    this.$('svg .edgePath').each(function(argument) {
+                        var childNode = $(this).find('marker');
+                        $(this).find('marker').remove();
+                        var eleRef = this;
+                        ++that.IEGraphRenderDone;
+                        setTimeout(function(argument) {
+                            $(eleRef).find('defs').append(childNode);
+                            --that.IEGraphRenderDone;
+                            if (that.IEGraphRenderDone === 0) {
+                                this.$('.fontLoader').hide();
+                                this.$('svg').fadeTo(1000, 1)
+                            }
+                        }, 1000);
                     });
                 }
                 LineageUtils.DragNode({
                     svg: this.svg,
                     g: this.g,
-                    guid: this.guid,
-                    edgeEl: this.$('svg .edgePath')
+                    guid: this.guid
                 }).init();
             },
             renderLineageTypeSearch: function() {
@@ -875,7 +856,6 @@ define(['require',
                         guid: selectedNode,
                         svg: $(that.svg[0]),
                         g: that.g,
-                        edgeEl: $('svg .edgePath'),
                         afterCenterZoomed: function(options) {
                             var newScale = options.newScale,
                                 newTranslate = options.newTranslate;
@@ -969,7 +949,7 @@ define(['require',
                         scaleFactor = 1,
                         svgWidth = that.$('svg').width(),
                         svgHeight = that.$('svg').height();
-                    if (platform.name === "Firefox") {
+                    if (platform.name != "Chrome") {
                         svgClone.setAttribute('width', svgWidth);
                         svgClone.setAttribute('height', svgHeight);
                     }
@@ -1002,9 +982,6 @@ define(['require',
 
                     var img = new Image(canvas.width, canvas.height);
                     var svgBlob = new Blob([data], { type: 'image/svg+xml;base64' });
-                    if (platform.name === "Safari") {
-                        svgBlob = new Blob([data], { type: 'image/svg+xml' });
-                    }
                     var url = DOMURL.createObjectURL(svgBlob);
 
                     img.onload = function() {
@@ -1030,11 +1007,6 @@ define(['require',
                                 }
                                 a.click();
                                 that.toggleLoader(loaderTargetDiv);
-                                if (platform.name === 'Safari') {
-                                    LineageUtils.refreshGraphForSafari({
-                                        edgeEl: that.$('svg g.node')
-                                    });
-                                }
                             }, 'image/png');
                             $('.hidden-svg').html('');
                             createCanvas.remove();
