@@ -17,7 +17,7 @@
  */
 
 define(['require',
-    'hbs!tmpl/site/header',
+    'hbs!tmpl/site/Header',
     'utils/CommonViewFunction',
     'utils/Globals',
     'utils/Utils'
@@ -37,10 +37,10 @@ define(['require',
                 var queryParams = Utils.getUrlState.getQueryParams(),
                     urlPath = "searchUrl";
                 if (queryParams && queryParams.from) {
-                    if (queryParams.from == "tag") {
+                    if (queryParams.from == "classification") {
                         urlPath = "tagUrl";
-                    } else if (queryParams.from == "taxonomy") {
-                        urlPath = "taxonomyUrl";
+                    } else if(queryParams.from == "glossary"){
+                        urlPath = "glossaryUrl";
                     }
                 }
                 Utils.setUrl({
