@@ -76,7 +76,7 @@ define(['require',
                         tagName: null
                     }
                 };
-                if (this.value && this.value.viewType) {
+                if (Utils.getUrlState.isTagTab() && this.value && this.value.viewType) {
                     this.viewType = this.value.viewType;
                 }
                 this.query[this.viewType].tagName = this.tag;
@@ -119,15 +119,12 @@ define(['require',
                 this.ui.treeLov.empty();
                 var treeStr = '<option></option>';
                 this.collection.fullCollection.each(function(model) {
-                    var name = Utils.getName(model.toJSON(), 'name'),
-                        checkTagOrTerm = Utils.checkTagOrTerm(name);
-                    if (checkTagOrTerm && checkTagOrTerm.tag) {
-                        treeStr += '<option>' + (name) + '</option>';
-                    }
+                    var name = Utils.getName(model.toJSON(), 'name');
+                    treeStr += '<option>' + (name) + '</option>';
                 });
                 that.ui.treeLov.html(treeStr);
                 that.ui.treeLov.select2({
-                    placeholder: "Search tag",
+                    placeholder: "Search Classification",
                     allowClear: true
                 });
             },
@@ -212,7 +209,7 @@ define(['require',
                 var tagParents = '',
                     tagLists = '';
 
-                if (this.collection && this.collection.fullCollection.length) {
+                if (this.collection && this.collection.fullCollection.length >= 0) {
                     var sortedCollection = this.collection.fullCollection;
                     this.tagTreeList = this.getTagTreeList({ collection: sortedCollection });
                     if (searchString) {
@@ -258,13 +255,10 @@ define(['require',
                 collection.each(function(model) {
                     var modelJSON = model.toJSON();
                     if (modelJSON.superTypes.length == 0) {
-                        var name = modelJSON.name,
-                            checkTagOrTerm = Utils.checkTagOrTerm(name);
-                        if (checkTagOrTerm && checkTagOrTerm.tag) {
-                            listOfParents[name] = {
-                                name: name,
-                                children: getChildren({ children: modelJSON.subTypes })
-                            }
+                        var name = modelJSON.name;
+                        listOfParents[name] = {
+                            name: name,
+                            children: getChildren({ children: modelJSON.subTypes })
                         }
                     }
                 });
@@ -294,25 +288,23 @@ define(['require',
                     });
                 } else {
                     data.each(function(obj) {
-                        var name = obj.get('name'),
-                            checkTagOrTerm = Utils.checkTagOrTerm(name);
-                        if (checkTagOrTerm && checkTagOrTerm.tag) {
-                            if (searchString) {
-                                if (name.search(new RegExp(searchString, "i")) != -1) {
-                                    element += getElString({
-                                        name: obj.get('name'),
-                                        children: null
-                                    });
-                                } else {
-                                    return;
-                                }
-                            } else {
+                        var name = obj.get('name');
+                        if (searchString) {
+                            if (name.search(new RegExp(searchString, "i")) != -1) {
                                 element += getElString({
                                     name: obj.get('name'),
                                     children: null
                                 });
+                            } else {
+                                return;
                             }
+                        } else {
+                            element += getElString({
+                                name: obj.get('name'),
+                                children: null
+                            });
                         }
+
                     });
                 }
                 return element;
@@ -357,7 +349,7 @@ define(['require',
                     var name = (!(nodeName == "BUTTON") ? that.query[that.viewType].tagName : null);
                     var view = new CreateTagLayoutView({ 'tagCollection': that.collection, 'selectedTag': name, 'enumDefCollection': enumDefCollection }),
                         modal = new Modal({
-                            title: 'Create a new tag',
+                            title: 'Create a new classification',
                             content: view,
                             cancelText: "Cancel",
                             okCloses: false,
@@ -376,7 +368,7 @@ define(['require',
                     modal.on('shownModal', function() {
                         view.ui.parentTag.select2({
                             multiple: true,
-                            placeholder: "Search Tags",
+                            placeholder: "Search Classification",
                             allowClear: true
                         });
                     });
@@ -501,7 +493,7 @@ define(['require',
                         that.collection.fullCollection.add(classificationDefs);
                         that.setUrl('#!/tag/tagAttribute/' + ref.ui.tagName.val(), true);
                         Utils.notifySuccess({
-                            content: "Tag " + that.name + Messages.addSuccessMessage
+                            content: "Classification " + that.name + Messages.addSuccessMessage
                         });
                         modal.trigger('cancel');
                         that.typeHeaders.fetch({ reset: true });
@@ -537,9 +529,9 @@ define(['require',
                     popoverOptions: {
                         content: function() {
                             return "<ul>" +
-                                "<li class='listTerm' ><i class='fa fa-search'></i> <a href='javascript:void(0)' data-fn='onSearchTag'>Search Tag</a></li>" +
-                                "<li class='listTerm' ><i class='fa fa-plus'></i> <a href='javascript:void(0)' data-fn='onClickCreateTag'>Create Sub-tag</a></li>" +
-                                "<li class='listTerm' ><i class='fa fa-trash-o'></i> <a href='javascript:void(0)' data-fn='onDeleteTag'>Delete Tag</a></li>" +
+                                "<li class='listTerm' ><i class='fa fa-search'></i> <a href='javascript:void(0)' data-fn='onSearchTag'>Search Classification</a></li>" +
+                                "<li class='listTerm' ><i class='fa fa-plus'></i> <a href='javascript:void(0)' data-fn='onClickCreateTag'>Create Sub-classification</a></li>" +
+                                "<li class='listTerm' ><i class='fa fa-trash-o'></i> <a href='javascript:void(0)' data-fn='onDeleteTag'>Delete Classification</a></li>" +
                                 "</ul>";
                         }
                     }
@@ -571,25 +563,18 @@ define(['require',
                         },
                         cancel: function(argument) {}
                     }
-                var text = "Are you sure you want to delete the tag"
+                var text = "Are you sure you want to delete the classification"
                 notifyObj['text'] = text;
                 Utils.notifyConfirm(notifyObj);
             },
             onNotifyOk: function(data) {
                 var that = this,
-                    deleteTagData = this.collection.fullCollection.findWhere({ name: this.tag }),
-                    classificationData = deleteTagData.toJSON(),
-                    deleteJson = {
-                        classificationDefs: [classificationData],
-                        entityDefs: [],
-                        enumDefs: [],
-                        structDefs: []
-                    };
+                    deleteTagData = this.collection.fullCollection.findWhere({ name: this.tag });
                 deleteTagData.deleteTag({
                     typeName: that.tag,
                     success: function() {
                         Utils.notifySuccess({
-                            content: "Tag " + that.tag + Messages.deleteSuccessMessage
+                            content: "Classification " + that.tag + Messages.deleteSuccessMessage
                         });
                         // if deleted tag is prviously searched then remove that tag url from save state of tab.
                         var searchUrl = Globals.saveApplicationState.tabState.searchUrl;
