@@ -44,6 +44,19 @@ public final class ApplicationProperties extends PropertiesConfiguration {
 
     public static final String  APPLICATION_PROPERTIES     = "atlas-application.properties";
 
+    public static final String  GRAPHDB_BACKEND_CONF       = "atlas.graphdb.backend";
+    public static final String  STORAGE_BACKEND_CONF       = "atlas.graph.storage.backend";
+    public static final String  INDEX_BACKEND_CONF         = "atlas.graph.index.search.backend";
+    public static final String  INDEX_MAP_NAME_CONF        = "atlas.graph.index.search.map-name";
+    public static final String  SOLR_WAIT_SEARCHER_CONF    = "atlas.graph.index.search.solr.wait-searcher";
+    public static final String  GRAPHBD_BACKEND_JANUS      = "janus";
+    public static final String  STORAGE_BACKEND_HBASE      = "hbase";
+    public static final String  STORAGE_BACKEND_HBASE2     = "hbase2";
+    public static final String  INDEX_BACKEND_SOLR         = "solr";
+    public static final String  DEFAULT_GRAPHDB_BACKEND    = GRAPHBD_BACKEND_JANUS;
+    public static final boolean DEFAULT_SOLR_WAIT_SEARCHER = true;
+    public static final boolean DEFAULT_INDEX_MAP_NAME     = false;
+
     public static final SimpleEntry<String, String> DB_CACHE_CONF               = new SimpleEntry<>("atlas.graph.cache.db-cache", "true");
     public static final SimpleEntry<String, String> DB_CACHE_CLEAN_WAIT_CONF    = new SimpleEntry<>("atlas.graph.cache.db-cache-clean-wait", "20");
     public static final SimpleEntry<String, String> DB_CACHE_SIZE_CONF          = new SimpleEntry<>("atlas.graph.cache.db-cache-size", "0.5");
@@ -248,6 +261,50 @@ public final class ApplicationProperties extends PropertiesConfiguration {
     }
 
     private void setDefaults() {
+        // setting value for 'atlas.graphdb.backend' (default = 'janus')
+        String graphDbBackend = getString(GRAPHDB_BACKEND_CONF);
+
+        if (StringUtils.isEmpty(graphDbBackend)) {
+            graphDbBackend = DEFAULT_GRAPHDB_BACKEND;
+        }
+
+        clearPropertyDirect(GRAPHDB_BACKEND_CONF);
+        addPropertyDirect(GRAPHDB_BACKEND_CONF, graphDbBackend);
+        LOG.info("Using graphdb backend '" + graphDbBackend + "'");
+
+        // setting value for 'atlas.graph.storage.backend' (default = 'hbase2')
+        String storageBackend = getString(STORAGE_BACKEND_CONF);
+
+        if (StringUtils.isEmpty(storageBackend) || storageBackend.equalsIgnoreCase(STORAGE_BACKEND_HBASE)) {
+            storageBackend = STORAGE_BACKEND_HBASE2;
+        }
+
+        clearPropertyDirect(STORAGE_BACKEND_CONF);
+        addPropertyDirect(STORAGE_BACKEND_CONF, storageBackend);
+        LOG.info("Using storage backend '" + storageBackend + "'");
+
+        // setting value for 'atlas.graph.index.search.backend' (default = 'solr')
+        String indexBackend = getString(INDEX_BACKEND_CONF);
+
+        if (StringUtils.isEmpty(indexBackend)) {
+            indexBackend = INDEX_BACKEND_SOLR;
+        }
+
+        clearPropertyDirect(INDEX_BACKEND_CONF);
+        addPropertyDirect(INDEX_BACKEND_CONF, indexBackend);
+        LOG.info("Using index backend '" + indexBackend + "'");
+
+        // set the following if indexing backend is 'solr'
+        if (indexBackend.equalsIgnoreCase(INDEX_BACKEND_SOLR)) {
+            clearPropertyDirect(SOLR_WAIT_SEARCHER_CONF);
+            addPropertyDirect(SOLR_WAIT_SEARCHER_CONF, DEFAULT_SOLR_WAIT_SEARCHER);
+            LOG.info("Setting solr-wait-searcher property '" + DEFAULT_SOLR_WAIT_SEARCHER + "'");
+
+            clearPropertyDirect(INDEX_MAP_NAME_CONF);
+            addPropertyDirect(INDEX_MAP_NAME_CONF, DEFAULT_INDEX_MAP_NAME);
+            LOG.info("Setting index.search.map-name property '" + DEFAULT_INDEX_MAP_NAME + "'");
+        }
+
         setDbCacheConfDefaults();
     }
 
