@@ -116,14 +116,12 @@ public class AtlasTypeRegistry {
         return ret;
     }
 
-    public AtlasType getTypeByGuid(String guid) throws AtlasBaseException {
+    public AtlasType getTypeByGuid(String guid) {
         if (LOG.isDebugEnabled()) {
             LOG.debug("==> AtlasTypeRegistry.getTypeByGuid({})", guid);
         }
 
         AtlasType ret = registryData.allTypes.getTypeByGuid(guid);
-        if(ret == null)
-            throw new AtlasBaseException(AtlasErrorCode.TYPE_GUID_NOT_FOUND, guid);
 
         if (LOG.isDebugEnabled()) {
             LOG.debug("<== AtlasTypeRegistry.getTypeByGuid({}): {}", guid, ret);
@@ -395,9 +393,9 @@ public class AtlasTypeRegistry {
 
             if (typeDef != null) {
                 addTypeWithNoRefResolve(typeDef);
-            }
 
-            resolveReferences();
+                resolveReferences();
+            }
 
             if (LOG.isDebugEnabled()) {
                 LOG.debug("<== AtlasTypeRegistry.addType({})", typeDef);
@@ -423,9 +421,9 @@ public class AtlasTypeRegistry {
 
             if (CollectionUtils.isNotEmpty(typeDefs)) {
                 addTypesWithNoRefResolve(typeDefs);
-            }
 
-            resolveReferences();
+                resolveReferences();
+            }
 
             if (LOG.isDebugEnabled()) {
                 LOG.debug("<== AtlasTypeRegistry.addTypes(length={})", (typeDefs == null ? 0 : typeDefs.size()));
@@ -443,9 +441,9 @@ public class AtlasTypeRegistry {
                 addTypesWithNoRefResolve(typesDef.getClassificationDefs());
                 addTypesWithNoRefResolve(typesDef.getEntityDefs());
                 addTypesWithNoRefResolve(typesDef.getRelationshipDefs());
-            }
 
-            resolveReferences();
+                resolveReferences();
+            }
 
             if (LOG.isDebugEnabled()) {
                 LOG.debug("<== AtlasTypeRegistry.addTypes({})", typesDef);
@@ -459,9 +457,9 @@ public class AtlasTypeRegistry {
 
             if (typeDef != null) {
                 updateTypeWithNoRefResolve(typeDef);
-            }
 
-            resolveReferences();
+                resolveReferences();
+            }
 
             if (LOG.isDebugEnabled()) {
                 LOG.debug("<== AtlasTypeRegistry.updateType({})", typeDef);
@@ -475,9 +473,9 @@ public class AtlasTypeRegistry {
 
             if (guid != null && typeDef != null) {
                 updateTypeByGuidWithNoRefResolve(guid, typeDef);
-            }
 
-            resolveReferences();
+                resolveReferences();
+            }
 
             if (LOG.isDebugEnabled()) {
                 LOG.debug("<== AtlasTypeRegistry.updateTypeByGuid({})", guid);
@@ -491,9 +489,9 @@ public class AtlasTypeRegistry {
 
             if (name != null && typeDef != null) {
                 updateTypeByNameWithNoRefResolve(name, typeDef);
-            }
 
-            resolveReferences();
+                resolveReferences();
+            }
 
             if (LOG.isDebugEnabled()) {
                 LOG.debug("<== AtlasTypeRegistry.updateEnumDefByName({})", name);
@@ -507,9 +505,9 @@ public class AtlasTypeRegistry {
 
             if (CollectionUtils.isNotEmpty(typeDefs)) {
                 updateTypesWithNoRefResolve(typeDefs);
-            }
 
-            resolveReferences();
+                resolveReferences();
+            }
 
             if (LOG.isDebugEnabled()) {
                 LOG.debug("<== AtlasTypeRegistry.updateTypes(length={})", (typeDefs == null ? 0 : typeDefs.size()));
@@ -523,9 +521,9 @@ public class AtlasTypeRegistry {
 
             if (typesDef != null) {
                 updateTypesWithNoRefResolve(typesDef);
-            }
 
-            resolveReferences();
+                resolveReferences();
+            }
 
             if (LOG.isDebugEnabled()) {
                 LOG.debug("<== AtlasTypeRegistry.updateTypes({})", typesDef);
@@ -557,9 +555,9 @@ public class AtlasTypeRegistry {
                 removeTypesWithNoRefResolve(typesDef.getClassificationDefs());
                 removeTypesWithNoRefResolve(typesDef.getEntityDefs());
                 removeTypesWithNoRefResolve(typesDef.getRelationshipDefs());
-            }
 
-            resolveReferences();
+                resolveReferences();
+            }
         }
 
         private void removeTypesWithNoRefResolve(Collection<? extends AtlasBaseTypeDef> typeDefs) {
@@ -621,16 +619,16 @@ public class AtlasTypeRegistry {
                 LOG.debug("==> AtlasTypeRegistry.removeTypeByGuid({})", guid);
             }
 
-            AtlasBaseTypeDef typeDef = getTypeDefByGuid(guid);
-
             if (guid != null) {
+                AtlasBaseTypeDef typeDef = getTypeDefByGuid(guid);
+
                 registryData.removeByGuid(guid);
-            }
 
-            resolveReferences();
+                resolveReferences();
 
-            if (typeDef != null) {
-                deletedTypes.add(typeDef);
+                if (typeDef != null) {
+                    deletedTypes.add(typeDef);
+                }
             }
 
             if (LOG.isDebugEnabled()) {
@@ -643,16 +641,16 @@ public class AtlasTypeRegistry {
                 LOG.debug("==> AtlasTypeRegistry.removeTypeByName({})", name);
             }
 
-            AtlasBaseTypeDef typeDef = getTypeDefByName(name);
-
             if (name != null) {
+                AtlasBaseTypeDef typeDef = getTypeDefByName(name);
+
                 registryData.removeByName(name);
-            }
 
-            resolveReferences();
+                resolveReferences();
 
-            if (typeDef != null) {
-                deletedTypes.add(typeDef);
+                if (typeDef != null) {
+                    deletedTypes.add(typeDef);
+                }
             }
 
             if (LOG.isDebugEnabled()) {
