@@ -278,6 +278,10 @@ public class AtlasTypeUtil {
         return new AtlasEntityDef(name, description, version, Arrays.asList(attrDefs), superTypes);
     }
 
+    public static AtlasEntityDef createClassTypeDef(String name, String description, String version, Set<String> superTypes, Map<String, String> options, AtlasAttributeDef... attrDefs) {
+        return new AtlasEntityDef(name, description, version, Arrays.asList(attrDefs), superTypes, options);
+    }
+
     public static AtlasRelationshipDef createRelationshipTypeDef(String                  name,
                                                                  String                  description,
                                                                  String                  version,
@@ -290,6 +294,10 @@ public class AtlasTypeUtil {
                                         endDef1, endDef2, Arrays.asList(attrDefs));
     }
 
+    public static AtlasRelationshipEndDef createRelationshipEndDef(String typeName, String name, Cardinality cardinality, boolean isContainer) {
+        return new AtlasRelationshipEndDef(typeName, name, cardinality, isContainer);
+    }
+
     public static AtlasTypesDef getTypesDef(List<AtlasEnumDef> enums,
         List<AtlasStructDef> structs,
         List<AtlasClassificationDef> traits,
@@ -297,6 +305,14 @@ public class AtlasTypeUtil {
         return new AtlasTypesDef(enums, structs, traits, classes);
     }
 
+    public static AtlasTypesDef getTypesDef(List<AtlasEnumDef> enums,
+                                            List<AtlasStructDef> structs,
+                                            List<AtlasClassificationDef> traits,
+                                            List<AtlasEntityDef> classes,
+                                            List<AtlasRelationshipDef> relations) {
+        return new AtlasTypesDef(enums, structs, traits, classes, relations);
+    }
+
     public static List<AtlasTypeDefHeader> toTypeDefHeader(AtlasTypesDef typesDef) {
         List<AtlasTypeDefHeader> headerList = new LinkedList<>();
         if (CollectionUtils.isNotEmpty(typesDef.getEnumDefs())) {
@@ -334,6 +350,8 @@ public class AtlasTypeUtil {
         if (typeDef != null) {
             if (typeDef.getClass().equals(AtlasEntityDef.class)) {
                 ret.getEntityDefs().add((AtlasEntityDef) typeDef);
+            } else if (typeDef.getClass().equals(AtlasRelationshipDef.class)) {
+                ret.getRelationshipDefs().add((AtlasRelationshipDef) typeDef);
             } else if (typeDef.getClass().equals(AtlasClassificationDef.class)) {
                 ret.getClassificationDefs().add((AtlasClassificationDef) typeDef);
             } else if (typeDef.getClass().equals(AtlasStructDef.class)) {
@@ -360,6 +378,20 @@ public class AtlasTypeUtil {
         return ret;
     }
 
+    public static Collection<AtlasRelatedObjectId> toAtlasRelatedObjectIds(Collection<AtlasEntity> entities) {
+        List<AtlasRelatedObjectId> ret = new ArrayList<>();
+
+        if (CollectionUtils.isNotEmpty(entities)) {
+            for (AtlasEntity entity : entities) {
+                if (entity != null) {
+                    ret.add(toAtlasRelatedObjectId(entity));
+                }
+            }
+        }
+
+        return ret;
+    }
+
     public static Map toStructAttributes(Map map) {
         if (map != null && map.containsKey("typeName") && map.containsKey("attributes") && map.get("attributes") instanceof Map) {
             return (Map)map.get("attributes");
@@ -649,4 +681,4 @@ public class AtlasTypeUtil {
             }
         }
     }
-}
+}
\ No newline at end of file
