@@ -20,35 +20,28 @@ package org.apache.atlas.repository.converters;
 import org.apache.atlas.AtlasErrorCode;
 import org.apache.atlas.AtlasException;
 import org.apache.atlas.CreateUpdateEntitiesResult;
+import org.apache.atlas.EntityAuditEvent;
 import org.apache.atlas.RequestContext;
+import org.apache.atlas.model.audit.EntityAuditEventV2;
 import org.apache.atlas.exception.AtlasBaseException;
 import org.apache.atlas.model.TypeCategory;
 import org.apache.atlas.model.instance.AtlasClassification;
 import org.apache.atlas.model.instance.AtlasEntity;
 import org.apache.atlas.model.instance.AtlasEntity.AtlasEntitiesWithExtInfo;
+import org.apache.atlas.model.instance.AtlasEntity.AtlasEntityWithExtInfo;
 import org.apache.atlas.model.instance.AtlasEntityHeader;
 import org.apache.atlas.model.instance.EntityMutationResponse;
-import org.apache.atlas.model.instance.EntityMutations;
 import org.apache.atlas.model.instance.EntityMutations.EntityOperation;
 import org.apache.atlas.model.instance.GuidMapping;
 import org.apache.atlas.model.legacy.EntityResult;
+import org.apache.atlas.repository.store.graph.v2.EntityGraphRetriever;
+import org.apache.atlas.v1.model.instance.Referenceable;
+import org.apache.atlas.v1.model.instance.Struct;
 import org.apache.atlas.repository.converters.AtlasFormatConverter.ConverterContext;
-import org.apache.atlas.services.MetadataService;
 import org.apache.atlas.type.AtlasClassificationType;
 import org.apache.atlas.type.AtlasEntityType;
 import org.apache.atlas.type.AtlasType;
 import org.apache.atlas.type.AtlasTypeRegistry;
-import org.apache.atlas.typesystem.IReferenceableInstance;
-import org.apache.atlas.typesystem.IStruct;
-import org.apache.atlas.typesystem.ITypedReferenceableInstance;
-import org.apache.atlas.typesystem.ITypedStruct;
-import org.apache.atlas.typesystem.Referenceable;
-import org.apache.atlas.typesystem.Struct;
-import org.apache.atlas.typesystem.exception.EntityExistsException;
-import org.apache.atlas.typesystem.exception.EntityNotFoundException;
-import org.apache.atlas.typesystem.exception.TraitNotFoundException;
-import org.apache.atlas.typesystem.exception.TypeNotFoundException;
-import org.apache.atlas.typesystem.types.ValueConversionException;
 import org.apache.commons.collections.CollectionUtils;
 import org.apache.commons.collections.MapUtils;
 import org.slf4j.Logger;
@@ -67,59 +60,55 @@ import java.util.Map;
 @Singleton
 @Component
 public class AtlasInstanceConverter {
-
     private static final Logger LOG = LoggerFactory.getLogger(AtlasInstanceConverter.class);
 
-    private AtlasTypeRegistry typeRegistry;
-
-    private AtlasFormatConverters instanceFormatters;
-
-    private MetadataService metadataService;
+    private final AtlasTypeRegistry     typeRegistry;
+    private final AtlasFormatConverters instanceFormatters;
+    private final EntityGraphRetriever  entityGraphRetriever;
 
     @Inject
-    public AtlasInstanceConverter(AtlasTypeRegistry typeRegistry, AtlasFormatConverters instanceFormatters, MetadataService metadataService) {
-        this.typeRegistry = typeRegistry;
-        this.instanceFormatters = instanceFormatters;
-        this.metadataService = metadataService;
+    public AtlasInstanceConverter(AtlasTypeRegistry typeRegistry, AtlasFormatConverters instanceFormatters) {
+        this.typeRegistry         = typeRegistry;
+        this.instanceFormatters   = instanceFormatters;
+        this.entityGraphRetriever = new EntityGraphRetriever(typeRegistry);
     }
 
-    public ITypedReferenceableInstance[] getITypedReferenceables(Collection<AtlasEntity> entities) throws AtlasBaseException {
-        ITypedReferenceableInstance[] entitiesInOldFormat = new ITypedReferenceableInstance[entities.size()];
+    public Referenceable[] getReferenceables(Collection<AtlasEntity> entities) throws AtlasBaseException {
+        Referenceable[] ret = new Referenceable[entities.size()];
 
         AtlasFormatConverter.ConverterContext ctx = new AtlasFormatConverter.ConverterContext();
+
         for(Iterator<AtlasEntity> i = entities.iterator(); i.hasNext(); ) {
             ctx.addEntity(i.next());
         }
 
         Iterator<AtlasEntity> entityIterator = entities.iterator();
         for (int i = 0; i < entities.size(); i++) {
-            ITypedReferenceableInstance typedInstance = getITypedReferenceable(entityIterator.next());
-            entitiesInOldFormat[i] = typedInstance;
+            ret[i] = getReferenceable(entityIterator.next(), ctx);
         }
-        return entitiesInOldFormat;
+
+        return ret;
     }
 
-    public ITypedReferenceableInstance getITypedReferenceable(AtlasEntity entity) throws AtlasBaseException {
-        return getITypedReferenceable(entity.getGuid());
+    public Referenceable getReferenceable(AtlasEntity entity) throws AtlasBaseException {
+        return getReferenceable(entity, new ConverterContext());
     }
 
-    public ITypedReferenceableInstance getITypedReferenceable(String guid) throws AtlasBaseException {
-        try {
-            ITypedReferenceableInstance ret = RequestContext.get().getInstanceV1(guid);
+    public Referenceable getReferenceable(String guid) throws AtlasBaseException {
+        AtlasEntityWithExtInfo entity = getAndCacheEntityExtInfo(guid);
 
-            if (ret == null) {
-                ret = metadataService.getEntityDefinition(guid);
+        return getReferenceable(entity);
+    }
 
-                if (ret != null) {
-                    RequestContext.get().cache(ret);
-                }
-            }
+    public Referenceable getReferenceable(AtlasEntityWithExtInfo entity) throws AtlasBaseException {
+        AtlasFormatConverter.ConverterContext ctx = new AtlasFormatConverter.ConverterContext();
 
-            return ret;
-        } catch (AtlasException e) {
-            LOG.error("Exception while getting a typed reference for the entity ", e);
-            throw toAtlasBaseException(e);
+        ctx.addEntity(entity.getEntity());
+        for(Map.Entry<String, AtlasEntity> entry : entity.getReferredEntities().entrySet()) {
+            ctx.addEntity(entry.getValue());
         }
+
+        return getReferenceable(entity.getEntity(), ctx);
     }
 
     public Referenceable getReferenceable(AtlasEntity entity, final ConverterContext ctx) throws AtlasBaseException {
@@ -130,31 +119,28 @@ public class AtlasInstanceConverter {
         return ref;
     }
 
-    public ITypedStruct getTrait(AtlasClassification classification) throws AtlasBaseException {
+    public Struct getTrait(AtlasClassification classification) throws AtlasBaseException {
         AtlasFormatConverter converter          = instanceFormatters.getConverter(TypeCategory.CLASSIFICATION);
         AtlasType            classificationType = typeRegistry.getType(classification.getTypeName());
         Struct               trait               = (Struct)converter.fromV2ToV1(classification, classificationType, new ConverterContext());
 
-        try {
-            return metadataService.createTraitInstance(trait);
-        } catch (AtlasException e) {
-            LOG.error("Exception while getting a typed reference for the entity ", e);
-            throw toAtlasBaseException(e);
-        }
+        return trait;
     }
 
-    public AtlasClassification getClassification(IStruct classification) throws AtlasBaseException {
-        AtlasFormatConverter converter          = instanceFormatters.getConverter(TypeCategory.CLASSIFICATION);
+    public AtlasClassification toAtlasClassification(Struct classification) throws AtlasBaseException {
+        AtlasFormatConverter    converter          = instanceFormatters.getConverter(TypeCategory.CLASSIFICATION);
         AtlasClassificationType classificationType = typeRegistry.getClassificationTypeByName(classification.getTypeName());
+
         if (classificationType == null) {
             throw new AtlasBaseException(AtlasErrorCode.TYPE_NAME_INVALID, TypeCategory.CLASSIFICATION.name(), classification.getTypeName());
         }
-        AtlasClassification  ret                = (AtlasClassification)converter.fromV1ToV2(classification, classificationType, new AtlasFormatConverter.ConverterContext());
+
+        AtlasClassification  ret = (AtlasClassification)converter.fromV1ToV2(classification, classificationType, new AtlasFormatConverter.ConverterContext());
 
         return ret;
     }
 
-    public AtlasEntitiesWithExtInfo toAtlasEntity(IReferenceableInstance referenceable) throws AtlasBaseException {
+    public AtlasEntitiesWithExtInfo toAtlasEntity(Referenceable referenceable) throws AtlasBaseException {
         AtlasEntityFormatConverter converter  = (AtlasEntityFormatConverter) instanceFormatters.getConverter(TypeCategory.ENTITY);
         AtlasEntityType            entityType = typeRegistry.getEntityTypeByName(referenceable.getTypeName());
 
@@ -162,13 +148,6 @@ public class AtlasInstanceConverter {
             throw new AtlasBaseException(AtlasErrorCode.TYPE_NAME_INVALID, TypeCategory.ENTITY.name(), referenceable.getTypeName());
         }
 
-        // validate
-        try {
-            metadataService.validateAndConvertToTypedInstance(referenceable, entityType.getTypeName());
-        } catch (AtlasException excp) {
-            throw toAtlasBaseException(excp);
-        }
-
         ConverterContext ctx    = new ConverterContext();
         AtlasEntity      entity = converter.fromV1ToV2(referenceable, entityType, ctx);
 
@@ -177,106 +156,59 @@ public class AtlasInstanceConverter {
         return ctx.getEntities();
     }
 
-    public static EntityMutationResponse toEntityMutationResponse(EntityResult entityResult) {
-
-        CreateUpdateEntitiesResult result = new CreateUpdateEntitiesResult();
-        result.setEntityResult(entityResult);
-        return toEntityMutationResponse(result);
-    }
-
-    public static EntityMutationResponse toEntityMutationResponse(CreateUpdateEntitiesResult result) {
-        EntityMutationResponse response = new EntityMutationResponse();
-        for (String guid : result.getCreatedEntities()) {
-            AtlasEntityHeader header = new AtlasEntityHeader();
-            header.setGuid(guid);
-            response.addEntity(EntityMutations.EntityOperation.CREATE, header);
-        }
-
-        for (String guid : result.getUpdatedEntities()) {
-            AtlasEntityHeader header = new AtlasEntityHeader();
-            header.setGuid(guid);
-            response.addEntity(EntityMutations.EntityOperation.UPDATE, header);
-        }
-
-        for (String guid : result.getDeletedEntities()) {
-            AtlasEntityHeader header = new AtlasEntityHeader();
-            header.setGuid(guid);
-            response.addEntity(EntityMutations.EntityOperation.DELETE, header);
-        }
-        GuidMapping guidMapping = result.getGuidMapping();
-        if(guidMapping != null) {
-            response.setGuidAssignments(guidMapping.getGuidAssignments());
-        }
-        return response;
-    }
-
-    public static AtlasBaseException toAtlasBaseException(AtlasException e) {
-        if (e instanceof EntityExistsException) {
-            return new AtlasBaseException(AtlasErrorCode.INSTANCE_ALREADY_EXISTS, e.getMessage());
-        }
-
-        if ( e instanceof EntityNotFoundException || e instanceof TraitNotFoundException) {
-            return new AtlasBaseException(AtlasErrorCode.INSTANCE_NOT_FOUND, e.getMessage());
-        }
-
-        if ( e instanceof TypeNotFoundException) {
-            return new AtlasBaseException(AtlasErrorCode.TYPE_NAME_NOT_FOUND, e.getMessage());
-        }
-
-        if (e instanceof ValueConversionException) {
-            return new AtlasBaseException(AtlasErrorCode.INVALID_VALUE, e, e.getMessage());
-        }
-
-        return new AtlasBaseException(AtlasErrorCode.BAD_REQUEST, e.getMessage());
-    }
-
 
     public AtlasEntity.AtlasEntitiesWithExtInfo toAtlasEntities(List<Referenceable> referenceables) throws AtlasBaseException {
         if (LOG.isDebugEnabled()) {
-            LOG.debug("==> toAtlasEntities");
+            LOG.debug("==> toAtlasEntities({})", referenceables);
         }
 
         AtlasFormatConverter.ConverterContext context = new AtlasFormatConverter.ConverterContext();
+
         for (Referenceable referenceable : referenceables) {
             AtlasEntity entity = fromV1toV2Entity(referenceable, context);
 
             context.addEntity(entity);
         }
+
+        AtlasEntity.AtlasEntitiesWithExtInfo ret = context.getEntities();
+
         if (LOG.isDebugEnabled()) {
-            LOG.debug("<== toAtlasEntities");
+            LOG.debug("<== toAtlasEntities({}): ret=", referenceables, ret);
         }
 
-        return context.getEntities();
+        return ret;
     }
 
-    public AtlasEntitiesWithExtInfo toAtlasEntities(String entitiesJson) throws AtlasBaseException, AtlasException {
-        ITypedReferenceableInstance[] referenceables = metadataService.deserializeClassInstances(entitiesJson);
-        AtlasEntityFormatConverter    converter      = (AtlasEntityFormatConverter) instanceFormatters.getConverter(TypeCategory.ENTITY);
-        ConverterContext              context        = new ConverterContext();
-        AtlasEntitiesWithExtInfo      ret            = null;
+    public AtlasEntitiesWithExtInfo toAtlasEntities(String[] jsonEntities) throws AtlasBaseException, AtlasException {
+        Referenceable[] referenceables = new Referenceable[jsonEntities.length];
 
-        if (referenceables != null) {
-            for (IReferenceableInstance referenceable : referenceables) {
-                AtlasEntityType entityType = typeRegistry.getEntityTypeByName(referenceable.getTypeName());
+        for (int i = 0; i < jsonEntities.length; i++) {
+            referenceables[i] = AtlasType.fromV1Json(jsonEntities[i], Referenceable.class);
+        }
 
-                if (entityType == null) {
-                    throw new AtlasBaseException(AtlasErrorCode.TYPE_NAME_INVALID, TypeCategory.ENTITY.name(), referenceable.getTypeName());
-                }
+        AtlasEntityFormatConverter converter = (AtlasEntityFormatConverter) instanceFormatters.getConverter(TypeCategory.ENTITY);
+        ConverterContext           context   = new ConverterContext();
 
-                AtlasEntity entity = converter.fromV1ToV2(referenceable, entityType, context);
+        for (Referenceable referenceable : referenceables) {
+            AtlasEntityType entityType = typeRegistry.getEntityTypeByName(referenceable.getTypeName());
 
-                context.addEntity(entity);
+            if (entityType == null) {
+                throw new AtlasBaseException(AtlasErrorCode.TYPE_NAME_INVALID, TypeCategory.ENTITY.name(), referenceable.getTypeName());
             }
 
-            ret = context.getEntities();
+            AtlasEntity entity = converter.fromV1ToV2(referenceable, entityType, context);
+
+            context.addEntity(entity);
         }
 
+        AtlasEntitiesWithExtInfo ret = context.getEntities();
+
         return ret;
     }
 
     private AtlasEntity fromV1toV2Entity(Referenceable referenceable, AtlasFormatConverter.ConverterContext context) throws AtlasBaseException {
         if (LOG.isDebugEnabled()) {
-            LOG.debug("==> fromV1toV2Entity");
+            LOG.debug("==> fromV1toV2Entity({})", referenceable);
         }
 
         AtlasEntityFormatConverter converter = (AtlasEntityFormatConverter) instanceFormatters.getConverter(TypeCategory.ENTITY);
@@ -284,8 +216,9 @@ public class AtlasInstanceConverter {
         AtlasEntity entity = converter.fromV1ToV2(referenceable, typeRegistry.getType(referenceable.getTypeName()), context);
 
         if (LOG.isDebugEnabled()) {
-            LOG.debug("<== fromV1toV2Entity");
+            LOG.debug("<== fromV1toV2Entity({}): {}", referenceable, entity);
         }
+
         return entity;
     }
 
@@ -358,4 +291,142 @@ public class AtlasInstanceConverter {
 
         return ret;
     }
-}
+
+    public AtlasEntity getAndCacheEntity(String guid) throws AtlasBaseException {
+        RequestContext context = RequestContext.get();
+        AtlasEntity    entity  = context.getEntity(guid);
+
+        if (entity == null) {
+            entity = entityGraphRetriever.toAtlasEntity(guid);
+
+            if (entity != null) {
+                context.cache(entity);
+
+                if (LOG.isDebugEnabled()) {
+                    LOG.debug("Cache miss -> GUID = {}", guid);
+                }
+            }
+        }
+
+        return entity;
+    }
+
+
+    public AtlasEntityWithExtInfo getAndCacheEntityExtInfo(String guid) throws AtlasBaseException {
+        RequestContext         context           = RequestContext.get();
+        AtlasEntityWithExtInfo entityWithExtInfo = context.getEntityWithExtInfo(guid);
+
+        if (entityWithExtInfo == null) {
+            entityWithExtInfo = entityGraphRetriever.toAtlasEntityWithExtInfo(guid);
+
+            if (entityWithExtInfo != null) {
+                context.cache(entityWithExtInfo);
+
+                if (LOG.isDebugEnabled()) {
+                    LOG.debug("Cache miss -> GUID = {}", guid);
+                }
+            }
+        }
+
+        return entityWithExtInfo;
+    }
+
+    public EntityAuditEvent toV1AuditEvent(EntityAuditEventV2 v2Event) throws AtlasBaseException {
+        EntityAuditEvent ret = new EntityAuditEvent();
+
+        ret.setEntityId(v2Event.getEntityId());
+        ret.setTimestamp(v2Event.getTimestamp());
+        ret.setUser(v2Event.getUser());
+        ret.setDetails(v2Event.getDetails());
+        ret.setEventKey(v2Event.getEventKey());
+
+        ret.setAction(getV1AuditAction(v2Event.getAction()));
+        ret.setEntityDefinition(getReferenceable(v2Event.getEntityId()));
+
+        return ret;
+    }
+
+    public EntityAuditEventV2 toV2AuditEvent(EntityAuditEvent v1Event) throws AtlasBaseException {
+        EntityAuditEventV2 ret = new EntityAuditEventV2();
+
+        ret.setEntityId(v1Event.getEntityId());
+        ret.setTimestamp(v1Event.getTimestamp());
+        ret.setUser(v1Event.getUser());
+        ret.setDetails(v1Event.getDetails());
+        ret.setEventKey(v1Event.getEventKey());
+        ret.setAction(getV2AuditAction(v1Event.getAction()));
+
+        AtlasEntitiesWithExtInfo entitiesWithExtInfo = toAtlasEntity(v1Event.getEntityDefinition());
+
+        if (entitiesWithExtInfo != null && CollectionUtils.isNotEmpty(entitiesWithExtInfo.getEntities())) {
+            // there will only one source entity
+            AtlasEntity entity = entitiesWithExtInfo.getEntities().get(0);
+
+            ret.setEntity(entity);
+        }
+
+        return ret;
+    }
+
+    private EntityAuditEvent.EntityAuditAction getV1AuditAction(EntityAuditEventV2.EntityAuditActionV2 v2AuditAction) {
+        switch (v2AuditAction) {
+            case ENTITY_CREATE:
+                return EntityAuditEvent.EntityAuditAction.ENTITY_CREATE;
+            case ENTITY_UPDATE:
+                return EntityAuditEvent.EntityAuditAction.ENTITY_UPDATE;
+            case ENTITY_DELETE:
+                return EntityAuditEvent.EntityAuditAction.ENTITY_DELETE;
+            case ENTITY_IMPORT_CREATE:
+                return EntityAuditEvent.EntityAuditAction.ENTITY_IMPORT_CREATE;
+            case ENTITY_IMPORT_UPDATE:
+                return EntityAuditEvent.EntityAuditAction.ENTITY_IMPORT_UPDATE;
+            case ENTITY_IMPORT_DELETE:
+                return EntityAuditEvent.EntityAuditAction.ENTITY_IMPORT_DELETE;
+            case CLASSIFICATION_ADD:
+                return EntityAuditEvent.EntityAuditAction.TAG_ADD;
+            case CLASSIFICATION_DELETE:
+                return EntityAuditEvent.EntityAuditAction.TAG_DELETE;
+            case CLASSIFICATION_UPDATE:
+                return EntityAuditEvent.EntityAuditAction.TAG_UPDATE;
+            case PROPAGATED_CLASSIFICATION_ADD:
+                return EntityAuditEvent.EntityAuditAction.PROPAGATED_TAG_ADD;
+            case PROPAGATED_CLASSIFICATION_DELETE:
+                return EntityAuditEvent.EntityAuditAction.PROPAGATED_TAG_DELETE;
+            case PROPAGATED_CLASSIFICATION_UPDATE:
+                return EntityAuditEvent.EntityAuditAction.PROPAGATED_TAG_UPDATE;
+        }
+
+        return null;
+    }
+
+    private EntityAuditEventV2.EntityAuditActionV2 getV2AuditAction(EntityAuditEvent.EntityAuditAction v1AuditAction) {
+        switch (v1AuditAction) {
+            case ENTITY_CREATE:
+                return EntityAuditEventV2.EntityAuditActionV2.ENTITY_CREATE;
+            case ENTITY_UPDATE:
+                return EntityAuditEventV2.EntityAuditActionV2.ENTITY_UPDATE;
+            case ENTITY_DELETE:
+                return EntityAuditEventV2.EntityAuditActionV2.ENTITY_DELETE;
+            case ENTITY_IMPORT_CREATE:
+                return EntityAuditEventV2.EntityAuditActionV2.ENTITY_IMPORT_CREATE;
+            case ENTITY_IMPORT_UPDATE:
+                return EntityAuditEventV2.EntityAuditActionV2.ENTITY_IMPORT_UPDATE;
+            case ENTITY_IMPORT_DELETE:
+                return EntityAuditEventV2.EntityAuditActionV2.ENTITY_IMPORT_DELETE;
+            case TAG_ADD:
+                return EntityAuditEventV2.EntityAuditActionV2.CLASSIFICATION_ADD;
+            case TAG_DELETE:
+                return EntityAuditEventV2.EntityAuditActionV2.CLASSIFICATION_DELETE;
+            case TAG_UPDATE:
+                return EntityAuditEventV2.EntityAuditActionV2.CLASSIFICATION_UPDATE;
+            case PROPAGATED_TAG_ADD:
+                return EntityAuditEventV2.EntityAuditActionV2.PROPAGATED_CLASSIFICATION_ADD;
+            case PROPAGATED_TAG_DELETE:
+                return EntityAuditEventV2.EntityAuditActionV2.PROPAGATED_CLASSIFICATION_DELETE;
+            case PROPAGATED_TAG_UPDATE:
+                return EntityAuditEventV2.EntityAuditActionV2.PROPAGATED_CLASSIFICATION_UPDATE;
+        }
+
+        return null;
+    }
+}
\ No newline at end of file
