@@ -21,7 +21,6 @@ package org.apache.atlas.repository.store.bootstrap;
 import com.fasterxml.jackson.annotation.JsonAutoDetect;
 import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
 import com.fasterxml.jackson.databind.annotation.JsonSerialize;
-
 import org.apache.atlas.AtlasErrorCode;
 import org.apache.atlas.AtlasException;
 import org.apache.atlas.RequestContext;
@@ -29,6 +28,7 @@ import org.apache.atlas.authorize.AtlasAuthorizerFactory;
 import org.apache.atlas.exception.AtlasBaseException;
 import org.apache.atlas.ha.HAConfiguration;
 import org.apache.atlas.listener.ActiveStateChangeHandler;
+import org.apache.atlas.model.patches.AtlasPatch.PatchStatus;
 import org.apache.atlas.model.typedef.AtlasBaseTypeDef;
 import org.apache.atlas.model.typedef.AtlasClassificationDef;
 import org.apache.atlas.model.typedef.AtlasEntityDef;
@@ -40,6 +40,8 @@ import org.apache.atlas.model.typedef.AtlasRelationshipEndDef;
 import org.apache.atlas.model.typedef.AtlasStructDef;
 import org.apache.atlas.model.typedef.AtlasStructDef.AtlasAttributeDef;
 import org.apache.atlas.model.typedef.AtlasTypesDef;
+import org.apache.atlas.repository.graphdb.AtlasGraph;
+import org.apache.atlas.repository.patches.AtlasPatchRegistry;
 import org.apache.atlas.store.AtlasTypeDefStore;
 import org.apache.atlas.type.AtlasEntityType;
 import org.apache.atlas.type.AtlasStructType.AtlasAttribute;
@@ -53,6 +55,7 @@ import org.apache.commons.lang.ObjectUtils;
 import org.apache.commons.lang3.StringUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import org.springframework.core.annotation.Order;
 import org.springframework.stereotype.Service;
 
 import javax.annotation.PostConstruct;
@@ -71,43 +74,44 @@ import java.util.Map;
 
 import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
 import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;
+import static org.apache.atlas.model.patches.AtlasPatch.PatchStatus.APPLIED;
+import static org.apache.atlas.model.patches.AtlasPatch.PatchStatus.FAILED;
+import static org.apache.atlas.model.patches.AtlasPatch.PatchStatus.SKIPPED;
+import static org.apache.atlas.model.patches.AtlasPatch.PatchStatus.UNKNOWN;
 
 /**
  * Class that handles initial loading of models and patches into typedef store
  */
 @Service
+@Order(2)
 public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
-    private static final Logger LOG = LoggerFactory.getLogger(AtlasTypeDefStoreInitializer.class);
+    public static final Logger LOG                    = LoggerFactory.getLogger(AtlasTypeDefStoreInitializer.class);
     public static final String PATCHES_FOLDER_NAME    = "patches";
     public static final String RELATIONSHIP_LABEL     = "relationshipLabel";
     public static final String RELATIONSHIP_CATEGORY  = "relationshipCategory";
     public static final String RELATIONSHIP_SWAP_ENDS = "swapEnds";
+    public static final String TYPEDEF_PATCH_TYPE     = "TYPEDEF_PATCH";
 
-    private final AtlasTypeDefStore atlasTypeDefStore;
-    private final AtlasTypeRegistry atlasTypeRegistry;
+    private final AtlasTypeDefStore typeDefStore;
+    private final AtlasTypeRegistry typeRegistry;
     private final Configuration     conf;
-
+    private final AtlasGraph        graph;
 
     @Inject
-    public AtlasTypeDefStoreInitializer(AtlasTypeDefStore atlasTypeDefStore, AtlasTypeRegistry atlasTypeRegistry, Configuration conf) {
-        this.atlasTypeDefStore = atlasTypeDefStore;
-        this.atlasTypeRegistry = atlasTypeRegistry;
-        this.conf              = conf;
+    public AtlasTypeDefStoreInitializer(AtlasTypeDefStore typeDefStore, AtlasTypeRegistry typeRegistry,
+                                        AtlasGraph graph, Configuration conf) {
+        this.typeDefStore  = typeDefStore;
+        this.typeRegistry  = typeRegistry;
+        this.conf          = conf;
+        this.graph         = graph;
     }
 
     @PostConstruct
-    public void init() throws AtlasBaseException {
+    public void init() {
         LOG.info("==> AtlasTypeDefStoreInitializer.init()");
 
         if (!HAConfiguration.isHAEnabled(conf)) {
-            atlasTypeDefStore.init();
-            loadBootstrapTypeDefs();
-
-            try {
-                AtlasAuthorizerFactory.getAtlasAuthorizer();
-            } catch (Throwable t) {
-                LOG.error("AtlasTypeDefStoreInitializer.init(): Unable to obtain AtlasAuthorizer", t);
-            }
+            startInternal();
         } else {
             LOG.info("AtlasTypeDefStoreInitializer.init(): deferring type loading until instance activation");
         }
@@ -132,8 +136,9 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
             LOG.info("Types directory {} does not exist or not readable or has no typedef files", modelsDirName);
         } else {
             // look for folders we need to load models from
-            File   topModeltypesDir  = new File(modelsDirName);
-            File[] modelsDirContents = topModeltypesDir.exists() ? topModeltypesDir.listFiles() : null;
+            File               topModeltypesDir  = new File(modelsDirName);
+            File[]             modelsDirContents = topModeltypesDir.exists() ? topModeltypesDir.listFiles() : null;
+            AtlasPatchRegistry patchRegistry     = new AtlasPatchRegistry(graph);
 
             if (modelsDirContents != null && modelsDirContents.length > 0) {
 	            Arrays.sort(modelsDirContents);
@@ -144,14 +149,15 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
 	                        continue;
 	                    } else if (!folder.getName().equals(PATCHES_FOLDER_NAME)){
 	                        // load the models alphabetically in the subfolders apart from patches
-	                        loadModelsInFolder(folder);
+	                        loadModelsInFolder(folder, patchRegistry);
 	                    }
 	            }
             }
 
             // load any files in the top models folder and any associated patches.
-            loadModelsInFolder(topModeltypesDir);
+            loadModelsInFolder(topModeltypesDir, patchRegistry);
         }
+
         LOG.info("<== AtlasTypeDefStoreInitializer.loadBootstrapTypeDefs()");
     }
 
@@ -159,7 +165,7 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
      * Load all the model files in the supplied folder followed by the contents of the patches folder.
      * @param typesDir
      */
-    private void loadModelsInFolder(File typesDir) {
+    private void loadModelsInFolder(File typesDir, AtlasPatchRegistry patchRegistry) {
         LOG.info("==> AtlasTypeDefStoreInitializer({})", typesDir);
 
         String typesDirName = typesDir.getName();
@@ -168,7 +174,6 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
         if (typeDefFiles == null || typeDefFiles.length == 0) {
             LOG.info("Types directory {} does not exist or not readable or has no typedef files", typesDirName );
         } else {
-
             // sort the files by filename
             Arrays.sort(typeDefFiles);
 
@@ -184,11 +189,11 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
                             continue;
                         }
 
-                        AtlasTypesDef typesToCreate = getTypesToCreate(typesDef, atlasTypeRegistry);
-                        AtlasTypesDef typesToUpdate = getTypesToUpdate(typesDef, atlasTypeRegistry, true);
+                        AtlasTypesDef typesToCreate = getTypesToCreate(typesDef, typeRegistry);
+                        AtlasTypesDef typesToUpdate = getTypesToUpdate(typesDef, typeRegistry, true);
 
                         if (!typesToCreate.isEmpty() || !typesToUpdate.isEmpty()) {
-                            atlasTypeDefStore.createUpdateTypesDef(typesToCreate, typesToUpdate);
+                            typeDefStore.createUpdateTypesDef(typesToCreate, typesToUpdate);
 
                             LOG.info("Created/Updated types defined in file {}", typeDefFile.getAbsolutePath());
                         } else {
@@ -201,7 +206,7 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
                 }
             }
 
-            applyTypePatches(typesDir.getPath());
+            applyTypePatches(typesDir.getPath(), patchRegistry);
         }
         LOG.info("<== AtlasTypeDefStoreInitializer({})", typesDir);
     }
@@ -337,12 +342,17 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
     }
 
     @Override
-    public void instanceIsActive() throws AtlasException {
+    public void instanceIsActive() {
         LOG.info("==> AtlasTypeDefStoreInitializer.instanceIsActive()");
 
-        try {
-            atlasTypeDefStore.init();
+        startInternal();
 
+        LOG.info("<== AtlasTypeDefStoreInitializer.instanceIsActive()");
+    }
+
+    private void startInternal() {
+        try {
+            typeDefStore.init();
             loadBootstrapTypeDefs();
 
             try {
@@ -353,8 +363,6 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
         } catch (AtlasBaseException e) {
             LOG.error("Failed to init after becoming active", e);
         }
-
-        LOG.info("<== AtlasTypeDefStoreInitializer.instanceIsActive()");
     }
 
     @Override
@@ -399,7 +407,7 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
         return ret;
     }
 
-    private void applyTypePatches(String typesDirName) {
+    private void applyTypePatches(String typesDirName, AtlasPatchRegistry patchRegistry) {
         String typePatchesDirName = typesDirName + File.separator + PATCHES_FOLDER_NAME;
         File   typePatchesDir     = new File(typePatchesDirName);
         File[] typePatchFiles     = typePatchesDir.exists() ? typePatchesDir.listFiles() : null;
@@ -413,11 +421,11 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
             Arrays.sort(typePatchFiles);
 
             PatchHandler[] patchHandlers = new PatchHandler[] {
-                    new AddAttributePatchHandler(atlasTypeDefStore, atlasTypeRegistry),
-                    new UpdateAttributePatchHandler(atlasTypeDefStore, atlasTypeRegistry),
-                    new RemoveLegacyRefAttributesPatchHandler(atlasTypeDefStore, atlasTypeRegistry),
-                    new UpdateTypeDefOptionsPatchHandler(atlasTypeDefStore, atlasTypeRegistry),
-                    new SetServiceTypePatchHandler(atlasTypeDefStore, atlasTypeRegistry)
+                    new AddAttributePatchHandler(typeDefStore, typeRegistry),
+                    new UpdateAttributePatchHandler(typeDefStore, typeRegistry),
+                    new RemoveLegacyRefAttributesPatchHandler(typeDefStore, typeRegistry),
+                    new UpdateTypeDefOptionsPatchHandler(typeDefStore, typeRegistry),
+                    new SetServiceTypePatchHandler(typeDefStore, typeRegistry)
             };
 
             Map<String, PatchHandler> patchHandlerRegistry = new HashMap<>();
@@ -430,37 +438,49 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
 
             for (File typePatchFile : typePatchFiles) {
                 if (typePatchFile.isFile()) {
+                    String patchFile = typePatchFile.getAbsolutePath();
 
-                    LOG.info("Applying patches in file {}", typePatchFile.getAbsolutePath());
+                    LOG.info("Applying patches in file {}", patchFile);
 
                     try {
-                        String jsonStr = new String(Files.readAllBytes(typePatchFile.toPath()), StandardCharsets.UTF_8);
+                        String         jsonStr = new String(Files.readAllBytes(typePatchFile.toPath()), StandardCharsets.UTF_8);
                         TypeDefPatches patches = AtlasType.fromJson(jsonStr, TypeDefPatches.class);
 
                         if (patches == null || CollectionUtils.isEmpty(patches.getPatches())) {
-                            LOG.info("No patches in file {}", typePatchFile.getAbsolutePath());
+                            LOG.info("No patches in file {}", patchFile);
 
                             continue;
                         }
 
+                        int patchIndex = 0;
                         for (TypeDefPatch patch : patches.getPatches()) {
                             PatchHandler patchHandler = patchHandlerRegistry.get(patch.getAction());
 
                             if (patchHandler == null) {
-                                LOG.error("Unknown patch action {} in file {}. Ignored",
-                                        patch.getAction(), typePatchFile.getAbsolutePath());
-
+                                LOG.error("Unknown patch action {} in file {}. Ignored", patch.getAction(), patchFile);
                                 continue;
                             }
 
-                            try {
-                                patchHandler.applyPatch(patch);
-                            } catch (AtlasBaseException excp) {
-                                LOG.error("Failed to apply {} patch in file {}. Ignored", patch.getAction(), typePatchFile.getAbsolutePath(), excp);
+                            if (patchRegistry.isApplicable(patch.getId(), patchFile, patchIndex++)) {
+                                PatchStatus status;
+
+                                try {
+                                    status = patchHandler.applyPatch(patch);
+                                } catch (AtlasBaseException ex) {
+                                    status = FAILED;
+
+                                    LOG.error("Failed to apply {} (status: {}; action: {}) in file: {}. Ignored.",
+                                               patch.getId(), status.toString(), patch.getAction(), patchFile);
+                                }
+
+                                patchRegistry.register(patch.id, patch.description, TYPEDEF_PATCH_TYPE, patch.action, status);
+                                LOG.info("{} (status: {}; action: {}) in file: {}", patch.getId(), status.toString(), patch.getAction(), patchFile);
+                            } else {
+                                LOG.info("{} in file: {} already {}. Ignoring.", patch.getId(), patchFile, patchRegistry.getStatus(patch.getId()).toString());
                             }
                         }
                     } catch (Throwable t) {
-                        LOG.error("Failed to apply patches in file {}. Ignored", typePatchFile.getAbsolutePath(), t);
+                        LOG.error("Failed to apply patches in file {}. Ignored", patchFile, t);
                     }
                 }
             }
@@ -476,6 +496,8 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
     @XmlRootElement
     @XmlAccessorType(XmlAccessType.PROPERTY)
     static class TypeDefPatch {
+        private String                  id;
+        private String                  description;
         private String                  action;
         private String                  typeName;
         private String                  applyToVersion;
@@ -485,6 +507,22 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
         private Map<String, String>     typeDefOptions;
         private String                  serviceType;
 
+        public String getId() {
+            return id;
+        }
+
+        public void setId(String id) {
+            this.id = id;
+        }
+
+        public String getDescription() {
+            return description;
+        }
+
+        public void setDescription(String description) {
+            this.description = description;
+        }
+
         public String getAction() {
             return action;
         }
@@ -583,7 +621,7 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
 
         public String[] getSupportedActions() { return supportedActions; }
 
-        public abstract void applyPatch(TypeDefPatch patch) throws AtlasBaseException;
+        public abstract PatchStatus applyPatch(TypeDefPatch patch) throws AtlasBaseException;
 
         protected boolean isPatchApplicable(TypeDefPatch patch, AtlasBaseTypeDef currentTypeDef) {
             String currentVersion = currentTypeDef.getTypeVersion();
@@ -601,9 +639,10 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
         }
 
         @Override
-        public void applyPatch(TypeDefPatch patch) throws AtlasBaseException {
-            String           typeName = patch.getTypeName();
-            AtlasBaseTypeDef typeDef  = typeRegistry.getTypeDefByName(typeName);
+        public PatchStatus applyPatch(TypeDefPatch patch) throws AtlasBaseException {
+            String           typeName       = patch.getTypeName();
+            AtlasBaseTypeDef typeDef        = typeRegistry.getTypeDefByName(typeName);
+            PatchStatus      ret;
 
             if (typeDef == null) {
                 throw new AtlasBaseException(AtlasErrorCode.PATCH_FOR_UNKNOWN_TYPE, patch.getAction(), typeName);
@@ -616,35 +655,48 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
                     for (AtlasAttributeDef attributeDef : patch.getAttributeDefs()) {
                         updatedDef.addAttribute(attributeDef);
                     }
+
                     updatedDef.setTypeVersion(patch.getUpdateToVersion());
 
                     typeDefStore.updateEntityDefByName(typeName, updatedDef);
+
+                    ret = APPLIED;
                 } else if (typeDef.getClass().equals(AtlasClassificationDef.class)) {
                     AtlasClassificationDef updatedDef = new AtlasClassificationDef((AtlasClassificationDef)typeDef);
 
                     for (AtlasAttributeDef attributeDef : patch.getAttributeDefs()) {
                         updatedDef.addAttribute(attributeDef);
                     }
+
                     updatedDef.setTypeVersion(patch.getUpdateToVersion());
 
                     typeDefStore.updateClassificationDefByName(typeName, updatedDef);
+
+                    ret = APPLIED;
                 } else if (typeDef.getClass().equals(AtlasStructDef.class)) {
                     AtlasStructDef updatedDef = new AtlasStructDef((AtlasStructDef)typeDef);
 
                     for (AtlasAttributeDef attributeDef : patch.getAttributeDefs()) {
                         updatedDef.addAttribute(attributeDef);
                     }
+
                     updatedDef.setTypeVersion(patch.getUpdateToVersion());
 
                     typeDefStore.updateStructDefByName(typeName, updatedDef);
+
+                    ret = APPLIED;
                 } else {
-                    throw new AtlasBaseException(AtlasErrorCode.PATCH_NOT_APPLICABLE_FOR_TYPE,
-                            patch.getAction(), typeDef.getClass().getSimpleName());
+                    throw new AtlasBaseException(AtlasErrorCode.PATCH_NOT_APPLICABLE_FOR_TYPE, patch.getAction(), typeDef.getClass().getSimpleName());
                 }
             } else {
                 LOG.info("patch skipped: typeName={}; applyToVersion={}; updateToVersion={}",
-                        patch.getTypeName(), patch.getApplyToVersion(), patch.getUpdateToVersion());
+                          patch.getTypeName(), patch.getApplyToVersion(), patch.getUpdateToVersion());
+
+                ret = SKIPPED;
+
             }
+
+            return ret;
         }
     }
 
@@ -654,9 +706,10 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
         }
 
         @Override
-        public void applyPatch(TypeDefPatch patch) throws AtlasBaseException {
-            String           typeName = patch.getTypeName();
-            AtlasBaseTypeDef typeDef  = typeRegistry.getTypeDefByName(typeName);
+        public PatchStatus applyPatch(TypeDefPatch patch) throws AtlasBaseException {
+            String           typeName       = patch.getTypeName();
+            AtlasBaseTypeDef typeDef        = typeRegistry.getTypeDefByName(typeName);
+            PatchStatus      ret;
 
             if (typeDef == null) {
                 throw new AtlasBaseException(AtlasErrorCode.PATCH_FOR_UNKNOWN_TYPE, patch.getAction(), typeName);
@@ -671,6 +724,8 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
                     updatedDef.setTypeVersion(patch.getUpdateToVersion());
 
                     typeDefStore.updateEntityDefByName(typeName, updatedDef);
+
+                    ret = APPLIED;
                 } else if (typeDef.getClass().equals(AtlasClassificationDef.class)) {
                     AtlasClassificationDef updatedDef = new AtlasClassificationDef((AtlasClassificationDef)typeDef);
 
@@ -679,6 +734,8 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
                     updatedDef.setTypeVersion(patch.getUpdateToVersion());
 
                     typeDefStore.updateClassificationDefByName(typeName, updatedDef);
+
+                    ret = APPLIED;
                 } else if (typeDef.getClass().equals(AtlasStructDef.class)) {
                     AtlasStructDef updatedDef = new AtlasStructDef((AtlasStructDef)typeDef);
 
@@ -688,14 +745,18 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
 
                     typeDefStore.updateStructDefByName(typeName, updatedDef);
 
+                    ret = APPLIED;
                 } else {
-                    throw new AtlasBaseException(AtlasErrorCode.PATCH_NOT_APPLICABLE_FOR_TYPE,
-                                                 patch.getAction(), typeDef.getClass().getSimpleName());
+                    throw new AtlasBaseException(AtlasErrorCode.PATCH_NOT_APPLICABLE_FOR_TYPE, patch.getAction(), typeDef.getClass().getSimpleName());
                 }
             } else {
                 LOG.info("patch skipped: typeName={}; applyToVersion={}; updateToVersion={}",
                           patch.getTypeName(), patch.getApplyToVersion(), patch.getUpdateToVersion());
+
+                ret = SKIPPED;
             }
+
+            return ret;
         }
 
         private void addOrUpdateAttributes(AtlasStructDef structDef, List<AtlasAttributeDef> attributesToUpdate) {
@@ -717,9 +778,10 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
         }
 
         @Override
-        public void applyPatch(TypeDefPatch patch) throws AtlasBaseException {
-            String           typeName = patch.getTypeName();
-            AtlasBaseTypeDef typeDef  = typeRegistry.getTypeDefByName(typeName);
+        public PatchStatus applyPatch(TypeDefPatch patch) throws AtlasBaseException {
+            String           typeName       = patch.getTypeName();
+            AtlasBaseTypeDef typeDef        = typeRegistry.getTypeDefByName(typeName);
+            PatchStatus      ret            = UNKNOWN;
 
             if (typeDef == null) {
                 throw new AtlasBaseException(AtlasErrorCode.PATCH_FOR_UNKNOWN_TYPE, patch.getAction(), typeName);
@@ -810,6 +872,8 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
                         RequestContext.get().setInTypePatching(true); // to allow removal of attributes
 
                         typeDefStore.updateTypesDef(typesDef);
+
+                        ret = APPLIED;
                     } finally {
                         RequestContext.get().setInTypePatching(false);
                     }
@@ -817,7 +881,11 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
             } else {
                 LOG.info("patch skipped: typeName={}; applyToVersion={}; updateToVersion={}",
                          patch.getTypeName(), patch.getApplyToVersion(), patch.getUpdateToVersion());
+
+                ret = SKIPPED;
             }
+
+            return ret;
         }
     }
 
@@ -827,9 +895,10 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
         }
 
         @Override
-        public void applyPatch(TypeDefPatch patch) throws AtlasBaseException {
+        public PatchStatus applyPatch(TypeDefPatch patch) throws AtlasBaseException {
             String           typeName = patch.getTypeName();
             AtlasBaseTypeDef typeDef  = typeRegistry.getTypeDefByName(typeName);
+            PatchStatus      ret;
 
             if (typeDef == null) {
                 throw new AtlasBaseException(AtlasErrorCode.PATCH_FOR_UNKNOWN_TYPE, patch.getAction(), typeName);
@@ -848,10 +917,16 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
                 typeDef.setTypeVersion(patch.getUpdateToVersion());
 
                 typeDefStore.updateTypesDef(AtlasTypeUtil.getTypesDef(typeDef));
+
+                ret = APPLIED;
             } else {
                 LOG.info("patch skipped: typeName={}; applyToVersion={}; updateToVersion={}",
                          patch.getTypeName(), patch.getApplyToVersion(), patch.getUpdateToVersion());
+
+                ret = SKIPPED;
             }
+
+            return ret;
         }
     }
 
@@ -861,9 +936,10 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
         }
 
         @Override
-        public void applyPatch(TypeDefPatch patch) throws AtlasBaseException {
-            String           typeName = patch.getTypeName();
-            AtlasBaseTypeDef typeDef  = typeRegistry.getTypeDefByName(typeName);
+        public PatchStatus applyPatch(TypeDefPatch patch) throws AtlasBaseException {
+            String           typeName       = patch.getTypeName();
+            AtlasBaseTypeDef typeDef        = typeRegistry.getTypeDefByName(typeName);
+            PatchStatus      ret;
 
             if (typeDef == null) {
                 throw new AtlasBaseException(AtlasErrorCode.PATCH_FOR_UNKNOWN_TYPE, patch.getAction(), typeName);
@@ -874,10 +950,16 @@ public class AtlasTypeDefStoreInitializer implements ActiveStateChangeHandler {
                 typeDef.setTypeVersion(patch.getUpdateToVersion());
 
                 typeDefStore.updateTypesDef(AtlasTypeUtil.getTypesDef(typeDef));
+
+                ret = APPLIED;
             } else {
-                LOG.info("patch skipped: typeName={}; applyToVersion={}; updateToVersion={}",
-                        patch.getTypeName(), patch.getApplyToVersion(), patch.getUpdateToVersion());
+                LOG.info("patch skipped: typeName={}; applyToVersion={}; updateToVersion={}", patch.getTypeName(),
+                          patch.getApplyToVersion(), patch.getUpdateToVersion());
+
+                ret = SKIPPED;
             }
+
+            return ret;
         }
     }
 }
