@@ -31,6 +31,7 @@ import org.apache.atlas.model.instance.AtlasEntityHeader;
 import org.apache.atlas.model.instance.AtlasObjectId;
 import org.apache.atlas.model.instance.AtlasRelationship;
 import org.apache.atlas.model.instance.AtlasRelationship.AtlasRelationshipWithExtInfo;
+import org.apache.atlas.model.notification.EntityNotification.EntityNotificationV2.OperationType;
 import org.apache.atlas.model.typedef.AtlasRelationshipDef;
 import org.apache.atlas.model.typedef.AtlasRelationshipDef.PropagateTags;
 import org.apache.atlas.model.typedef.AtlasRelationshipEndDef;
@@ -71,10 +72,12 @@ import static org.apache.atlas.model.instance.AtlasEntity.Status.DELETED;
 import static org.apache.atlas.model.typedef.AtlasRelationshipDef.PropagateTags.ONE_TO_TWO;
 import static org.apache.atlas.model.typedef.AtlasRelationshipDef.PropagateTags.TWO_TO_ONE;
 import static org.apache.atlas.repository.Constants.ENTITY_TYPE_PROPERTY_KEY;
+import static org.apache.atlas.repository.Constants.HOME_ID_KEY;
+import static org.apache.atlas.repository.Constants.PROVENANCE_TYPE_KEY;
 import static org.apache.atlas.repository.Constants.RELATIONSHIPTYPE_TAG_PROPAGATION_KEY;
 import static org.apache.atlas.repository.Constants.RELATIONSHIP_GUID_PROPERTY_KEY;
 import static org.apache.atlas.repository.Constants.VERSION_PROPERTY_KEY;
-import static org.apache.atlas.repository.Constants.PROVENANCE_TYPE_KEY;
+import static org.apache.atlas.AtlasConfiguration.NOTIFICATION_RELATIONSHIPS_ENABLED;
 
 
 import static org.apache.atlas.repository.graph.GraphHelper.getBlockedClassificationIds;
@@ -91,6 +94,7 @@ public class AtlasRelationshipStoreV2 implements AtlasRelationshipStore {
     private static final Logger LOG = LoggerFactory.getLogger(AtlasRelationshipStoreV2.class);
 
     private static final Long DEFAULT_RELATIONSHIP_VERSION = 0L;
+    private boolean notificationsEnabled = NOTIFICATION_RELATIONSHIPS_ENABLED.getBoolean();
 
     private final AtlasTypeRegistry         typeRegistry;
     private final EntityGraphRetriever      entityRetriever;
@@ -124,9 +128,6 @@ public class AtlasRelationshipStoreV2 implements AtlasRelationshipStore {
             LOG.debug("<== create({}): {}", relationship, ret);
         }
 
-        // notify entities for added/removed classification propagation
-        entityChangeNotifier.notifyPropagatedEntities();
-
         return ret;
     }
 
@@ -194,9 +195,7 @@ public class AtlasRelationshipStoreV2 implements AtlasRelationshipStore {
         validateRelationship(end1Vertex, end2Vertex, edgeType, relationship.getAttributes());
 
         AtlasRelationship ret = updateRelationship(edge, relationship);
-
-        // notify entities for added/removed classification propagation
-        entityChangeNotifier.notifyPropagatedEntities();
+        sendNotifications(ret, OperationType.RELATIONSHIP_UPDATE);
 
         if (LOG.isDebugEnabled()) {
             LOG.debug("<== update({}): {}", relationship, ret);
@@ -276,8 +275,7 @@ public class AtlasRelationshipStoreV2 implements AtlasRelationshipStore {
 
         deleteDelegate.getHandler().deleteRelationships(Collections.singleton(edge), forceDelete);
 
-        // notify entities for added/removed classification propagation
-        entityChangeNotifier.notifyPropagatedEntities();
+        sendNotifications(entityRetriever.mapEdgeToAtlasRelationship(edge), OperationType.RELATIONSHIP_DELETE);
 
         if (LOG.isDebugEnabled()) {
             LOG.debug("<== deleteById({}): {}", guid);
@@ -382,6 +380,7 @@ public class AtlasRelationshipStoreV2 implements AtlasRelationshipStore {
 
                 AtlasGraphUtilsV2.setEncodedProperty(ret, ENTITY_TYPE_PROPERTY_KEY, relationship.getTypeName());
                 AtlasGraphUtilsV2.setEncodedProperty(ret, RELATIONSHIP_GUID_PROPERTY_KEY, guid);
+                AtlasGraphUtilsV2.setEncodedProperty(ret, HOME_ID_KEY, relationship.getHomeId());
                 AtlasGraphUtilsV2.setEncodedProperty(ret, VERSION_PROPERTY_KEY, getRelationshipVersion(relationship));
                 AtlasGraphUtilsV2.setEncodedProperty(ret, PROVENANCE_TYPE_KEY, relationship.getProvenanceType());
                 AtlasGraphUtilsV2.setEncodedProperty(ret, RELATIONSHIPTYPE_TAG_PROPAGATION_KEY, tagPropagation.name());
@@ -406,6 +405,7 @@ public class AtlasRelationshipStoreV2 implements AtlasRelationshipStore {
             throw new AtlasBaseException(AtlasErrorCode.INTERNAL_ERROR, e);
         }
 
+        sendNotifications(entityRetriever.mapEdgeToAtlasRelationship(ret), OperationType.RELATIONSHIP_CREATE);
         return ret;
     }
 
@@ -506,6 +506,7 @@ public class AtlasRelationshipStoreV2 implements AtlasRelationshipStore {
     }
 
     // propagated classifications should contain blocked propagated classification
+
     private AtlasVertex validateBlockedPropagatedClassification(List<AtlasVertex> classificationVertices, AtlasClassification classification) {
         AtlasVertex ret = null;
 
@@ -521,7 +522,6 @@ public class AtlasRelationshipStoreV2 implements AtlasRelationshipStore {
 
         return ret;
     }
-
     private void addToBlockedClassificationIds(AtlasEdge edge, List<String> classificationIds) {
         if (edge != null) {
             if (classificationIds.isEmpty()) {
@@ -896,4 +896,11 @@ public class AtlasRelationshipStoreV2 implements AtlasRelationshipStore {
 
         return (attribute != null) ? attribute.getRelationshipEdgeLabel() : null;
     }
+
+    private void sendNotifications(AtlasRelationship ret, OperationType relationshipUpdate) throws AtlasBaseException {
+        entityChangeNotifier.notifyPropagatedEntities();
+        if (notificationsEnabled){
+            entityChangeNotifier.notifyRelationshipMutation(ret, relationshipUpdate);
+        }
+    }
 }
