@@ -84,17 +84,25 @@ import static org.apache.atlas.glossary.GlossaryUtils.TERM_ASSIGNMENT_ATTR_EXPRE
 import static org.apache.atlas.glossary.GlossaryUtils.TERM_ASSIGNMENT_ATTR_SOURCE;
 import static org.apache.atlas.glossary.GlossaryUtils.TERM_ASSIGNMENT_ATTR_STATUS;
 import static org.apache.atlas.glossary.GlossaryUtils.TERM_ASSIGNMENT_ATTR_STEWARD;
-import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.*;
+import static org.apache.atlas.model.instance.AtlasRelationship.Status.DELETED;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_BIGDECIMAL;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_BIGINTEGER;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_BOOLEAN;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_BYTE;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_DATE;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_DOUBLE;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_FLOAT;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_INT;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_LONG;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_SHORT;
+import static org.apache.atlas.model.typedef.AtlasBaseTypeDef.ATLAS_TYPE_STRING;
 import static org.apache.atlas.repository.Constants.CLASSIFICATION_ENTITY_GUID;
 import static org.apache.atlas.repository.Constants.CLASSIFICATION_LABEL;
 import static org.apache.atlas.repository.Constants.CLASSIFICATION_VALIDITY_PERIODS_KEY;
 import static org.apache.atlas.repository.Constants.TERM_ASSIGNMENT_LABEL;
-import static org.apache.atlas.repository.graph.GraphHelper.EDGE_LABEL_PREFIX;
-import static org.apache.atlas.repository.graph.GraphHelper.addToPropagatedTraitNames;
 import static org.apache.atlas.repository.graph.GraphHelper.getAdjacentEdgesByLabel;
 import static org.apache.atlas.repository.graph.GraphHelper.getAllClassificationEdges;
 import static org.apache.atlas.repository.graph.GraphHelper.getAllTraitNames;
-import static org.apache.atlas.repository.graph.GraphHelper.getAssociatedEntityVertex;
 import static org.apache.atlas.repository.graph.GraphHelper.getBlockedClassificationIds;
 import static org.apache.atlas.repository.graph.GraphHelper.getArrayElementsProperty;
 import static org.apache.atlas.repository.graph.GraphHelper.getClassificationEntityStatus;
@@ -759,7 +767,9 @@ public class EntityGraphRetriever {
         Map<String, AtlasObjectId> ret        = null;
         Map                        softRefVal = entityVertex.getProperty(attribute.getVertexPropertyName(), Map.class);
 
-        if (MapUtils.isNotEmpty(softRefVal)) {
+        if (MapUtils.isEmpty(softRefVal)) {
+            return softRefVal;
+        } else {
             ret = new HashMap<>();
 
             for (Object mapKey : softRefVal.keySet()) {
@@ -770,7 +780,6 @@ public class EntityGraphRetriever {
                 }
             }
         }
-
         return ret;
     }
 
@@ -778,7 +787,9 @@ public class EntityGraphRetriever {
         List<AtlasObjectId> ret        = null;
         List                softRefVal = entityVertex.getListProperty(attribute.getVertexPropertyName(), List.class);
 
-        if (CollectionUtils.isNotEmpty(softRefVal)) {
+        if (CollectionUtils.isEmpty(softRefVal)) {
+            return softRefVal;
+        } else {
             ret = new ArrayList<>();
 
             for (Object o : softRefVal) {
@@ -860,10 +871,6 @@ public class EntityGraphRetriever {
             ret = getPrimitiveMap(entityVertex, attribute.getVertexPropertyName());
         }
 
-        if (MapUtils.isEmpty(ret)) {
-            ret = null;
-        }
-
         return ret;
     }
 
@@ -874,14 +881,14 @@ public class EntityGraphRetriever {
         AtlasType      arrayElementType = arrayType.getElementType();
         List<Object>   arrayElements    = getArrayElementsProperty(arrayElementType, entityVertex, attribute);
 
-        if (CollectionUtils.isEmpty(arrayElements)) {
-            return null;
-        }
-
         if (LOG.isDebugEnabled()) {
             LOG.debug("Mapping array attribute {} for vertex {}", arrayElementType.getTypeName(), entityVertex);
         }
 
+        if (CollectionUtils.isEmpty(arrayElements)) {
+            return arrayElements;
+        }
+
         List                           arrValues     = new ArrayList(arrayElements.size());
         String                         edgeLabel     = attribute.getRelationshipEdgeLabel();
         AtlasRelationshipEdgeDirection edgeDirection = attribute.getRelationshipEdgeDirection();
@@ -936,7 +943,7 @@ public class EntityGraphRetriever {
         return ret;
     }
 
-    public Object mapVertexToPrimitive(AtlasElement entityVertex, final String vertexPropertyName, AtlasAttributeDef attrDef) {
+    public static Object mapVertexToPrimitive(AtlasElement entityVertex, final String vertexPropertyName, AtlasAttributeDef attrDef) {
         Object ret = null;
 
         if (AtlasGraphUtilsV2.getEncodedProperty(entityVertex, vertexPropertyName, Object.class) == null) {
@@ -1097,34 +1104,22 @@ public class EntityGraphRetriever {
             entity.setRelationshipAttribute(attributeName, ret);
 
             if (attributeEndDef.getIsLegacyAttribute() && !entity.hasAttribute(attributeName)) {
-                entity.setAttribute(attributeName, toAtlasObjectId(ret));
+                entity.setAttribute(attributeName, toLegacyAttribute(ret));
             }
         }
 
         return ret;
     }
 
-    private Object toAtlasObjectId(Object obj) {
+    private Object toLegacyAttribute(Object obj) {
         final Object ret;
 
-        if (obj instanceof AtlasObjectId) {
-            ret = new AtlasObjectId((AtlasObjectId) obj);
+        if (obj instanceof AtlasRelatedObjectId) {
+            ret = toLegacyAttribute((AtlasRelatedObjectId) obj);
         } else if (obj instanceof Collection) {
-            List list = new ArrayList();
-
-            for (Object elem : (Collection) obj) {
-                list.add(toAtlasObjectId(elem));
-            }
-
-            ret = list;
+            ret = toLegacyAttribute((Collection) obj);
         } else if (obj instanceof Map) {
-            Map map = new HashMap();
-
-            for (Object key : ((Map) obj).keySet()) {
-                map.put(key, toAtlasObjectId(((Map) obj).get(key)));
-            }
-
-            ret = map;
+            ret = toLegacyAttribute((Map) obj);
         } else {
             ret = obj;
         }
@@ -1132,6 +1127,46 @@ public class EntityGraphRetriever {
         return ret;
     }
 
+    private AtlasObjectId toLegacyAttribute(AtlasRelatedObjectId relatedObjId) {
+        final AtlasObjectId ret;
+
+        if (relatedObjId.getRelationshipStatus() == DELETED && relatedObjId.getEntityStatus() == AtlasEntity.Status.ACTIVE) {
+            ret = null;
+        } else {
+            ret = new AtlasObjectId(relatedObjId);
+        }
+
+        return ret;
+    }
+
+    private Collection toLegacyAttribute(Collection collection) {
+        final List ret = new ArrayList();
+
+        for (Object elem : collection) {
+            Object objId = toLegacyAttribute(elem);
+
+            if (objId != null) {
+                ret.add(objId);
+            }
+        }
+
+        return ret;
+    }
+
+    private Map toLegacyAttribute(Map map) {
+        final Map ret = new HashMap();
+
+        for (Object key : map.keySet()) {
+            Object elem = toLegacyAttribute(map.get(key));
+
+            if (elem != null) {
+                ret.put(key, elem);
+            }
+        }
+
+        return ret;
+    }
+
     private AtlasObjectId mapRelatedVertexToObjectId(AtlasVertex entityVertex, AtlasAttribute attribute, AtlasEntityExtInfo entityExtInfo, boolean isMinExtInfo) throws AtlasBaseException {
         AtlasEdge edge = graphHelper.getEdgeForLabel(entityVertex, attribute.getRelationshipEdgeLabel(), attribute.getRelationshipEdgeDirection());
 
@@ -1273,14 +1308,15 @@ public class EntityGraphRetriever {
             provenanceType = Integer.valueOf(0);
         }
         relationship.setProvenanceType(provenanceType);
+        relationship.setHomeId(GraphHelper.getHomeId(edge));
 
         relationship.setStatus(GraphHelper.getEdgeStatus(edge));
 
         AtlasVertex end1Vertex = edge.getOutVertex();
         AtlasVertex end2Vertex = edge.getInVertex();
 
-        relationship.setEnd1(new AtlasObjectId(getGuid(end1Vertex), getTypeName(end1Vertex)));
-        relationship.setEnd2(new AtlasObjectId(getGuid(end2Vertex), getTypeName(end2Vertex)));
+        relationship.setEnd1(new AtlasObjectId(getGuid(end1Vertex), getTypeName(end1Vertex), getEntityUniqueAttribute(end1Vertex)));
+        relationship.setEnd2(new AtlasObjectId(getGuid(end2Vertex), getTypeName(end2Vertex), getEntityUniqueAttribute(end2Vertex)));
 
         relationship.setLabel(edge.getLabel());
         relationship.setPropagateTags(getPropagateTags(edge));
