@@ -46,7 +46,11 @@ import org.apache.atlas.notification.NotificationInterface.NotificationType;
 import org.apache.atlas.notification.preprocessor.EntityPreprocessor;
 import org.apache.atlas.notification.preprocessor.PreprocessorContext;
 import org.apache.atlas.notification.preprocessor.PreprocessorContext.PreprocessAction;
+import org.apache.atlas.util.AtlasMetricsCounter;
+import org.apache.atlas.utils.AtlasJson;
 import org.apache.atlas.utils.LruCache;
+import org.apache.atlas.util.AtlasMetricsUtil;
+import org.apache.atlas.util.AtlasMetricsUtil.NotificationStat;
 import org.apache.atlas.v1.model.instance.Referenceable;
 import org.apache.atlas.v1.model.notification.HookNotificationV1.EntityCreateRequest;
 import org.apache.atlas.v1.model.notification.HookNotificationV1.EntityDeleteRequest;
@@ -76,6 +80,7 @@ import org.springframework.core.annotation.Order;
 import org.springframework.stereotype.Component;
 
 import javax.inject.Inject;
+import java.time.Instant;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
@@ -98,7 +103,7 @@ import static org.apache.atlas.notification.preprocessor.EntityPreprocessor.TYPE
  * Consumer of notifications from hooks e.g., hive hook etc.
  */
 @Component
-@Order(4)
+@Order(5)
 @DependsOn(value = {"atlasTypeDefStoreInitializer", "atlasTypeDefGraphStoreV2"})
 public class NotificationHookConsumer implements Service, ActiveStateChangeHandler {
     private static final Logger LOG        = LoggerFactory.getLogger(NotificationHookConsumer.class);
@@ -139,6 +144,7 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
     private final ServiceState                  serviceState;
     private final AtlasInstanceConverter        instanceConverter;
     private final AtlasTypeRegistry             typeRegistry;
+    private final AtlasMetricsUtil              metricsUtil;
     private final int                           maxRetries;
     private final int                           failedMsgCacheSize;
     private final int                           minWaitDuration;
@@ -154,10 +160,10 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
     private final boolean                       hiveTypesRemoveOwnedRefAttrs;
     private final boolean                       rdbmsTypesRemoveOwnedRefAttrs;
     private final boolean                       preprocessEnabled;
-
-    private NotificationInterface notificationInterface;
-    private ExecutorService       executors;
-    private Configuration         applicationProperties;
+    private final NotificationInterface         notificationInterface;
+    private final Configuration                 applicationProperties;
+    private       ExecutorService               executors;
+    private       Instant                       nextStatsLogTime = AtlasMetricsCounter.getNextHourStartTime(Instant.now());
 
     @VisibleForTesting
     final int consumerRetryInterval;
@@ -168,13 +174,14 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
     @Inject
     public NotificationHookConsumer(NotificationInterface notificationInterface, AtlasEntityStore atlasEntityStore,
                                     ServiceState serviceState, AtlasInstanceConverter instanceConverter,
-                                    AtlasTypeRegistry typeRegistry) throws AtlasException {
+                                    AtlasTypeRegistry typeRegistry, AtlasMetricsUtil metricsUtil) throws AtlasException {
         this.notificationInterface = notificationInterface;
         this.atlasEntityStore      = atlasEntityStore;
         this.serviceState          = serviceState;
         this.instanceConverter     = instanceConverter;
         this.typeRegistry          = typeRegistry;
         this.applicationProperties = ApplicationProperties.get();
+        this.metricsUtil           = metricsUtil;
 
         maxRetries            = applicationProperties.getInt(CONSUMER_RETRIES_PROPERTY, 3);
         failedMsgCacheSize    = applicationProperties.getInt(CONSUMER_FAILEDCACHESIZE_PROPERTY, 1);
@@ -238,8 +245,7 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
     @Override
     public void start() throws AtlasException {
         if (consumerDisabled) {
-            LOG.info("Hook consumer stopped. No hook messages will be processed. " +
-                    "Set property '{}' to false to start consuming hook messages.", CONSUMER_DISABLED);
+            LOG.info("No hook messages will be processed. {} = {}", CONSUMER_DISABLED, consumerDisabled);
             return;
         }
 
@@ -282,6 +288,10 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
     public void stop() {
         //Allow for completion of outstanding work
         try {
+            if (consumerDisabled) {
+                return;
+            }
+
             stopConsumerThreads();
             if (executors != null) {
                 executors.shutdown();
@@ -321,6 +331,10 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
      */
     @Override
     public void instanceIsActive() {
+        if (consumerDisabled) {
+            return;
+        }
+
         LOG.info("Reacting to active state: initializing Kafka consumers");
 
         startConsumers(executors);
@@ -334,6 +348,10 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
      */
     @Override
     public void instanceIsPassive() {
+        if (consumerDisabled) {
+            return;
+        }
+
         LOG.info("Reacting to passive state: shutting down Kafka consumers.");
 
         stop();
@@ -461,12 +479,12 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
 
         @VisibleForTesting
         void handleMessage(AtlasKafkaMessage<HookNotification> kafkaMsg) throws AtlasServiceException, AtlasException {
-            AtlasPerfTracer  perf        = null;
-            HookNotification message     = kafkaMsg.getMessage();
-            String           messageUser = message.getUser();
-            long             startTime   = System.currentTimeMillis();
-            boolean          isFailedMsg = false;
-            AuditLog         auditLog = null;
+            AtlasPerfTracer  perf           = null;
+            HookNotification message        = kafkaMsg.getMessage();
+            String           messageUser    = message.getUser();
+            long             startTime      = System.currentTimeMillis();
+            NotificationStat stats          = new NotificationStat();
+            AuditLog         auditLog       = null;
 
             if (AtlasPerfTracer.isPerfTraceEnabled(PERF_LOG)) {
                 perf = AtlasPerfTracer.getPerfTracer(PERF_LOG, message.getType().name());
@@ -511,7 +529,7 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                                                             AtlasClient.API_V1.CREATE_ENTITY.getNormalizedPath());
                                 }
 
-                                createOrUpdate(entities, false, context);
+                                createOrUpdate(entities, false, stats, context);
                             }
                             break;
 
@@ -532,7 +550,7 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                                 // There should only be one root entity
                                 entities.getEntities().get(0).setGuid(guid);
 
-                                createOrUpdate(entities, true, context);
+                                createOrUpdate(entities, true, stats, context);
                             }
                             break;
 
@@ -548,7 +566,9 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                                 try {
                                     AtlasEntityType type = (AtlasEntityType) typeRegistry.getType(deleteRequest.getTypeName());
 
-                                    atlasEntityStore.deleteByUniqueAttributes(type, Collections.singletonMap(deleteRequest.getAttribute(), (Object) deleteRequest.getAttributeValue()));
+                                    EntityMutationResponse response = atlasEntityStore.deleteByUniqueAttributes(type, Collections.singletonMap(deleteRequest.getAttribute(), (Object) deleteRequest.getAttributeValue()));
+
+                                    stats.updateStats(response);
                                 } catch (ClassCastException cle) {
                                     LOG.error("Failed to delete entity {}", deleteRequest);
                                 }
@@ -565,7 +585,7 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                                                             AtlasClientV2.API_V2.UPDATE_ENTITY.getNormalizedPath());
                                 }
 
-                                createOrUpdate(entities, false, context);
+                                createOrUpdate(entities, false, stats, context);
                             }
                             break;
 
@@ -579,7 +599,7 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                                                             AtlasClientV2.API_V2.CREATE_ENTITY.getNormalizedPath());
                                 }
 
-                                createOrUpdate(entities, false, context);
+                                createOrUpdate(entities, false, stats, context);
                             }
                             break;
 
@@ -594,7 +614,9 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                                                             AtlasClientV2.API_V2.UPDATE_ENTITY.getNormalizedPath());
                                 }
 
-                                atlasEntityStore.updateEntity(entityId, entity, true);
+                                EntityMutationResponse response = atlasEntityStore.updateEntity(entityId, entity, true);
+
+                                stats.updateStats(response);
                             }
                             break;
 
@@ -608,7 +630,7 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
                                                             AtlasClientV2.API_V2.UPDATE_ENTITY.getNormalizedPath());
                                 }
 
-                                createOrUpdate(entities, false, context);
+                                createOrUpdate(entities, false, stats, context);
                             }
                             break;
 
@@ -626,7 +648,9 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
 
                                         AtlasEntityType type = (AtlasEntityType) typeRegistry.getType(entity.getTypeName());
 
-                                        atlasEntityStore.deleteByUniqueAttributes(type, entity.getUniqueAttributes());
+                                        EntityMutationResponse response = atlasEntityStore.deleteByUniqueAttributes(type, entity.getUniqueAttributes());
+
+                                        stats.updateStats(response);
                                     }
                                 } catch (ClassCastException cle) {
                                     LOG.error("Failed to do delete entities {}", entities);
@@ -647,7 +671,7 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
 
                             LOG.warn("Max retries exceeded for message {}", strMessage, e);
 
-                            isFailedMsg = true;
+                            stats.isFailedMsg = true;
 
                             failedMessages.add(strMessage);
 
@@ -675,32 +699,42 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
             } finally {
                 AtlasPerfTracer.log(perf);
 
-                long msgProcessingTime = perf != null ? perf.getElapsedTime() : 0;
+                stats.timeTakenMs = System.currentTimeMillis() - startTime;
 
-                if (msgProcessingTime > largeMessageProcessingTimeThresholdMs) {
+                metricsUtil.onNotificationProcessingComplete(kafkaMsg.getOffset(), stats);
+
+                if (stats.timeTakenMs > largeMessageProcessingTimeThresholdMs) {
                     String strMessage = AbstractNotification.getMessageJson(message);
 
-                    LOG.warn("msgProcessingTime={}, msgSize={}, topicOffset={}}", msgProcessingTime, strMessage.length(), kafkaMsg.getOffset());
-                    LARGE_MESSAGES_LOG.warn("{\"msgProcessingTime\":{},\"msgSize\":{},\"topicOffset\":{},\"data\":{}}", msgProcessingTime, strMessage.length(), kafkaMsg.getOffset(), strMessage);
+                    LOG.warn("msgProcessingTime={}, msgSize={}, topicOffset={}}", stats.timeTakenMs, strMessage.length(), kafkaMsg.getOffset());
+                    LARGE_MESSAGES_LOG.warn("{\"msgProcessingTime\":{},\"msgSize\":{},\"topicOffset\":{},\"data\":{}}", stats.timeTakenMs, strMessage.length(), kafkaMsg.getOffset(), strMessage);
                 }
 
                 if (auditLog != null) {
-                    auditLog.setHttpStatus(isFailedMsg ? SC_BAD_REQUEST : SC_OK);
-                    auditLog.setTimeTaken(System.currentTimeMillis() - startTime);
+                    auditLog.setHttpStatus(stats.isFailedMsg ? SC_BAD_REQUEST : SC_OK);
+                    auditLog.setTimeTaken(stats.timeTakenMs);
 
                     AuditFilter.audit(auditLog);
                 }
+
+                Instant now = Instant.now();
+
+                if (now.isAfter(nextStatsLogTime)) {
+                    LOG.info("STATS: {}", AtlasJson.toJson(metricsUtil.getStats()));
+
+                    nextStatsLogTime = AtlasMetricsCounter.getNextHourStartTime(now);
+                }
             }
         }
 
-        private void createOrUpdate(AtlasEntitiesWithExtInfo entities, boolean isPartialUpdate, PreprocessorContext context) throws AtlasBaseException {
+        private void createOrUpdate(AtlasEntitiesWithExtInfo entities, boolean isPartialUpdate, NotificationStat stats, PreprocessorContext context) throws AtlasBaseException {
             List<AtlasEntity> entitiesList = entities.getEntities();
             AtlasEntityStream entityStream = new AtlasEntityStream(entities);
 
             if (commitBatchSize <= 0 || entitiesList.size() <= commitBatchSize) {
                 EntityMutationResponse response = atlasEntityStore.createOrUpdate(entityStream, isPartialUpdate);
 
-                recordProcessedEntities(response, context);
+                recordProcessedEntities(response, stats, context);
             } else {
                 for (int fromIdx = 0; fromIdx < entitiesList.size(); fromIdx += commitBatchSize) {
                     int toIndex = fromIdx + commitBatchSize;
@@ -718,7 +752,7 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
 
                     EntityMutationResponse response = atlasEntityStore.createOrUpdate(batchStream, isPartialUpdate);
 
-                    recordProcessedEntities(response, context);
+                    recordProcessedEntities(response, stats, context);
 
                     RequestContext.get().resetEntityGuidUpdates();
 
@@ -1004,24 +1038,30 @@ public class NotificationHookConsumer implements Service, ActiveStateChangeHandl
         return ret;
     }
 
-    private void recordProcessedEntities(EntityMutationResponse mutationResponse, PreprocessorContext context) {
-        if (mutationResponse != null && context != null) {
-            if (MapUtils.isNotEmpty(mutationResponse.getGuidAssignments())) {
-                context.getGuidAssignments().putAll(mutationResponse.getGuidAssignments());
+    private void recordProcessedEntities(EntityMutationResponse mutationResponse, NotificationStat stats, PreprocessorContext context) {
+        if (mutationResponse != null) {
+            if (stats != null) {
+                stats.updateStats(mutationResponse);
             }
 
-            if (CollectionUtils.isNotEmpty(mutationResponse.getCreatedEntities())) {
-                for (AtlasEntityHeader entity : mutationResponse.getCreatedEntities()) {
-                    if (entity != null && entity.getGuid() != null) {
-                        context.getCreatedEntities().add(entity.getGuid());
+            if (context != null) {
+                if (MapUtils.isNotEmpty(mutationResponse.getGuidAssignments())) {
+                    context.getGuidAssignments().putAll(mutationResponse.getGuidAssignments());
+                }
+
+                if (CollectionUtils.isNotEmpty(mutationResponse.getCreatedEntities())) {
+                    for (AtlasEntityHeader entity : mutationResponse.getCreatedEntities()) {
+                        if (entity != null && entity.getGuid() != null) {
+                            context.getCreatedEntities().add(entity.getGuid());
+                        }
                     }
                 }
-            }
 
-            if (CollectionUtils.isNotEmpty(mutationResponse.getDeletedEntities())) {
-                for (AtlasEntityHeader entity : mutationResponse.getDeletedEntities()) {
-                    if (entity != null && entity.getGuid() != null) {
-                        context.getDeletedEntities().add(entity.getGuid());
+                if (CollectionUtils.isNotEmpty(mutationResponse.getDeletedEntities())) {
+                    for (AtlasEntityHeader entity : mutationResponse.getDeletedEntities()) {
+                        if (entity != null && entity.getGuid() != null) {
+                            context.getDeletedEntities().add(entity.getGuid());
+                        }
                     }
                 }
             }
