@@ -21,6 +21,7 @@ package org.apache.atlas.web.resources;
 
 import org.apache.atlas.AtlasServiceException;
 import org.apache.atlas.exception.AtlasBaseException;
+import org.apache.atlas.model.impexp.AtlasExportResult;
 import org.apache.atlas.model.impexp.AtlasServer;
 import org.apache.atlas.model.impexp.AtlasExportRequest;
 import org.apache.atlas.model.impexp.AtlasImportRequest;
@@ -43,6 +44,7 @@ import static org.testng.Assert.assertTrue;
 
 public class AdminExportImportTestIT extends BaseResourceIT {
     private final String FILE_TO_IMPORT = "stocks-base.zip";
+    private final String FILE_TO_IMPORT_EMPTY = "empty-1.zip";
     private final String EXPORT_REQUEST_FILE = "export-incremental";
     private final String SOURCE_SERVER_NAME = "cl1";
 
@@ -62,6 +64,13 @@ public class AdminExportImportTestIT extends BaseResourceIT {
         assertReplicationData("cl1");
     }
 
+    @Test(dependsOnMethods = "isActive")
+    public void importEmptyData() throws AtlasServiceException {
+        AtlasImportResult result = performImportUsing(FILE_TO_IMPORT_EMPTY, new AtlasImportRequest());
+        assertNotNull(result);
+        assertEquals(AtlasExportResult.OperationStatus.FAIL.toString(), result.getOperationStatus().toString());
+    }
+
     @Test(dependsOnMethods = "importData")
     public void exportData() throws AtlasServiceException, IOException, AtlasBaseException {
         final int EXPECTED_CREATION_ORDER_SIZE = 10;
